
################################################################
# This is a generated script based on design: system
#
# Though there are limitations about the generated script,
# the main purpose of this utility is to make learning
# IP Integrator Tcl commands easier.
################################################################

################################################################
# Check if script is running in correct Vivado version.
################################################################
set scripts_vivado_version 2015.4
set current_vivado_version [version -short]

if { [string first $scripts_vivado_version $current_vivado_version] == -1 } {
   puts ""
   puts "ERROR: This script was generated using Vivado <$scripts_vivado_version> and is being run in <$current_vivado_version> of Vivado. Please run the script in Vivado <$scripts_vivado_version> then open the design in Vivado <$current_vivado_version>. Upgrade the design by running \"Tools => Report => Report IP Status...\", then run write_bd_tcl to create an updated script."

   return 1
}

################################################################
# START
################################################################

# To test this script, run the following commands from Vivado Tcl console:
# source system_script.tcl

# If you do not already have a project created,
# you can create a project using the following command:
#    create_project project_1 myproj -part xc7z030sbg485-1
#    set_property BOARD_PART trenz.biz:te0715-01-30-1c:part0:1.0 [current_project]

# CHECKING IF PROJECT EXISTS
if { [get_projects -quiet] eq "" } {
   puts "ERROR: Please open or create a project!"
   return 1
}



# CHANGE DESIGN NAME HERE
set design_name system

# If you do not already have an existing IP Integrator design open,
# you can create a design using the following command:
#    create_bd_design $design_name

# Creating design if needed
set errMsg ""
set nRet 0

set cur_design [current_bd_design -quiet]
set list_cells [get_bd_cells -quiet]

if { ${design_name} eq "" } {
   # USE CASES:
   #    1) Design_name not set

   set errMsg "ERROR: Please set the variable <design_name> to a non-empty value."
   set nRet 1

} elseif { ${cur_design} ne "" && ${list_cells} eq "" } {
   # USE CASES:
   #    2): Current design opened AND is empty AND names same.
   #    3): Current design opened AND is empty AND names diff; design_name NOT in project.
   #    4): Current design opened AND is empty AND names diff; design_name exists in project.

   if { $cur_design ne $design_name } {
      puts "INFO: Changing value of <design_name> from <$design_name> to <$cur_design> since current design is empty."
      set design_name [get_property NAME $cur_design]
   }
   puts "INFO: Constructing design in IPI design <$cur_design>..."

} elseif { ${cur_design} ne "" && $list_cells ne "" && $cur_design eq $design_name } {
   # USE CASES:
   #    5) Current design opened AND has components AND same names.

   set errMsg "ERROR: Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 1
} elseif { [get_files -quiet ${design_name}.bd] ne "" } {
   # USE CASES: 
   #    6) Current opened design, has components, but diff names, design_name exists in project.
   #    7) No opened design, design_name exists in project.

   set errMsg "ERROR: Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 2

} else {
   # USE CASES:
   #    8) No opened design, design_name not in project.
   #    9) Current opened design, has components, but diff names, design_name not in project.

   puts "INFO: Currently there is no design <$design_name> in project, so creating one..."

   create_bd_design $design_name

   puts "INFO: Making design <$design_name> as current_bd_design."
   current_bd_design $design_name

}

puts "INFO: Currently the variable <design_name> is equal to \"$design_name\"."

if { $nRet != 0 } {
   puts $errMsg
   return $nRet
}

##################################################################
# DESIGN PROCs
##################################################################


# Hierarchical cell: imageon_hdmi_out
proc create_hier_cell_imageon_hdmi_out { parentCell nameHier } {

  if { $parentCell eq "" || $nameHier eq "" } {
     puts "ERROR: create_hier_cell_imageon_hdmi_out() - Empty argument(s)!"
     return
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     puts "ERROR: Unable to find parent cell <$parentCell>!"
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     puts "ERROR: Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj

  # Create cell and set as current instance
  set hier_obj [create_bd_cell -type hier $nameHier]
  current_bd_instance $hier_obj

  # Create interface pins
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:axis_rtl:1.0 AXIS_vid_in
  create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 AXI_lite
  create_bd_intf_pin -mode Master -vlnv avnet.com:interface:avnet_hdmi_rtl:1.0 HDMI_vid_out

  # Create pins
  create_bd_pin -dir I -type clk axi_lite_clk
  create_bd_pin -dir I -from 0 -to 0 -type rst axi_lite_resetn
  create_bd_pin -dir I -type clk axis_clk
  create_bd_pin -dir I -from 0 -to 0 -type rst axis_resetn
  create_bd_pin -dir I vid_out_clk

  # Create instance: fmc_imageon_hdmi_out_0, and set properties
  set fmc_imageon_hdmi_out_0 [ create_bd_cell -type ip -vlnv avnet:fmc_imageon:fmc_imageon_hdmi_out:2.0 fmc_imageon_hdmi_out_0 ]

  # Create instance: v_axi4s_vid_out_0, and set properties
  set v_axi4s_vid_out_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:v_axi4s_vid_out:4.0 v_axi4s_vid_out_0 ]
  set_property -dict [ list \
CONFIG.C_ADDR_WIDTH {12} \
CONFIG.C_HAS_ASYNC_CLK {1} \
CONFIG.C_HYSTERESIS_LEVEL {3072} \
CONFIG.C_S_AXIS_VIDEO_FORMAT {0} \
CONFIG.C_VTG_MASTER_SLAVE {1} \
 ] $v_axi4s_vid_out_0

  # Create instance: v_tc_0, and set properties
  set v_tc_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:v_tc:6.1 v_tc_0 ]
  set_property -dict [ list \
CONFIG.VIDEO_MODE {1080p} \
CONFIG.enable_detection {false} \
 ] $v_tc_0

  # Create interface connections
  connect_bd_intf_net -intf_net AXIS_vid_in_1 [get_bd_intf_pins AXIS_vid_in] [get_bd_intf_pins v_axi4s_vid_out_0/video_in]
  connect_bd_intf_net -intf_net fmc_imageon_hdmi_out_0_IO_HDMIO [get_bd_intf_pins HDMI_vid_out] [get_bd_intf_pins fmc_imageon_hdmi_out_0/IO_HDMIO]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M01_AXI [get_bd_intf_pins AXI_lite] [get_bd_intf_pins v_tc_0/ctrl]
  connect_bd_intf_net -intf_net v_axi4s_vid_out_0_vid_io_out [get_bd_intf_pins fmc_imageon_hdmi_out_0/VID_IO_IN] [get_bd_intf_pins v_axi4s_vid_out_0/vid_io_out]
  connect_bd_intf_net -intf_net v_tc_0_vtiming_out [get_bd_intf_pins v_axi4s_vid_out_0/vtiming_in] [get_bd_intf_pins v_tc_0/vtiming_out]

  # Create port connections
  connect_bd_net -net axis_clk_1 [get_bd_pins axis_clk] [get_bd_pins v_axi4s_vid_out_0/aclk]
  connect_bd_net -net axis_resetn_1 [get_bd_pins axis_resetn] [get_bd_pins v_axi4s_vid_out_0/aresetn]
  connect_bd_net -net processing_system7_0_FCLK_CLK0 [get_bd_pins axi_lite_clk] [get_bd_pins v_tc_0/s_axi_aclk]
  connect_bd_net -net rst_processing_system7_0_50M_peripheral_aresetn [get_bd_pins axi_lite_resetn] [get_bd_pins v_tc_0/s_axi_aresetn]
  connect_bd_net -net util_ds_buf_0_IBUF_OUT [get_bd_pins vid_out_clk] [get_bd_pins fmc_imageon_hdmi_out_0/clk] [get_bd_pins v_axi4s_vid_out_0/vid_io_out_clk] [get_bd_pins v_tc_0/clk]
  connect_bd_net -net v_axi4s_vid_out_0_locked [get_bd_pins fmc_imageon_hdmi_out_0/oe] [get_bd_pins v_axi4s_vid_out_0/locked]
  connect_bd_net -net v_axi4s_vid_out_0_vtg_ce [get_bd_pins v_axi4s_vid_out_0/vtg_ce] [get_bd_pins v_tc_0/gen_clken]

  # Restore current instance
  current_bd_instance $oldCurInst
}

# Hierarchical cell: imageon_hdmi_in
proc create_hier_cell_imageon_hdmi_in { parentCell nameHier } {

  if { $parentCell eq "" || $nameHier eq "" } {
     puts "ERROR: create_hier_cell_imageon_hdmi_in() - Empty argument(s)!"
     return
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     puts "ERROR: Unable to find parent cell <$parentCell>!"
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     puts "ERROR: Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj

  # Create cell and set as current instance
  set hier_obj [create_bd_cell -type hier $nameHier]
  current_bd_instance $hier_obj

  # Create interface pins
  create_bd_intf_pin -mode Slave -vlnv avnet.com:interface:avnet_hdmi_rtl:1.0 IO_HDMII
  create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:axis_rtl:1.0 video_out

  # Create pins
  create_bd_pin -dir I -type clk aclk
  create_bd_pin -dir I -from 0 -to 0 -type rst aresetn
  create_bd_pin -dir I -type clk vid_io_in_clk

  # Create instance: fmc_imageon_hdmi_in_0, and set properties
  set fmc_imageon_hdmi_in_0 [ create_bd_cell -type ip -vlnv avnet:fmc_imageon:fmc_imageon_hdmi_in:2.0 fmc_imageon_hdmi_in_0 ]

  # Create instance: v_vid_in_axi4s_0, and set properties
  set v_vid_in_axi4s_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:v_vid_in_axi4s:4.0 v_vid_in_axi4s_0 ]
  set_property -dict [ list \
CONFIG.C_ADDR_WIDTH {12} \
CONFIG.C_HAS_ASYNC_CLK {1} \
CONFIG.C_M_AXIS_VIDEO_FORMAT {0} \
 ] $v_vid_in_axi4s_0

  # Create interface connections
  connect_bd_intf_net -intf_net HDMI_vid_in_1 [get_bd_intf_pins IO_HDMII] [get_bd_intf_pins fmc_imageon_hdmi_in_0/IO_HDMII]
  connect_bd_intf_net -intf_net fmc_imageon_hdmi_in_0_VID_IO_OUT [get_bd_intf_pins fmc_imageon_hdmi_in_0/VID_IO_OUT] [get_bd_intf_pins v_vid_in_axi4s_0/vid_io_in]
  connect_bd_intf_net -intf_net video_in_AXIS_vid_out [get_bd_intf_pins video_out] [get_bd_intf_pins v_vid_in_axi4s_0/video_out]

  # Create port connections
  connect_bd_net -net HDMI_vid_in_clk_1 [get_bd_pins vid_io_in_clk] [get_bd_pins fmc_imageon_hdmi_in_0/clk] [get_bd_pins v_vid_in_axi4s_0/vid_io_in_clk]
  connect_bd_net -net clkgen_150_MHz_clk_out1 [get_bd_pins aclk] [get_bd_pins v_vid_in_axi4s_0/aclk]
  connect_bd_net -net rst_sync_to_axis_clk_peripheral_aresetn [get_bd_pins aresetn] [get_bd_pins v_vid_in_axi4s_0/aresetn]

  # Restore current instance
  current_bd_instance $oldCurInst
}


# Procedure to create entire design; Provide argument to make
# procedure reusable. If parentCell is "", will use root.
proc create_root_design { parentCell } {

  if { $parentCell eq "" } {
     set parentCell [get_bd_cells /]
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     puts "ERROR: Unable to find parent cell <$parentCell>!"
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     puts "ERROR: Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj


  # Create interface ports
  set DDR [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:ddrx_rtl:1.0 DDR ]
  set FIXED_IO [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_processing_system7:fixedio_rtl:1.0 FIXED_IO ]
  set hdmii [ create_bd_intf_port -mode Slave -vlnv avnet.com:interface:avnet_hdmi_rtl:1.0 hdmii ]
  set hdmio [ create_bd_intf_port -mode Master -vlnv avnet.com:interface:avnet_hdmi_rtl:1.0 hdmio ]
  set imageon_iic [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:iic_rtl:1.0 imageon_iic ]

  # Create ports
  set hdmii_clk [ create_bd_port -dir I hdmii_clk ]
  set imageon_reset [ create_bd_port -dir O -from 0 -to 0 imageon_reset ]

  # Create instance: axi_ic_processing_system7_0_M_AXI_GP1, and set properties
  set axi_ic_processing_system7_0_M_AXI_GP1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 axi_ic_processing_system7_0_M_AXI_GP1 ]
  set_property -dict [ list \
CONFIG.M00_HAS_REGSLICE {1} \
CONFIG.M01_HAS_REGSLICE {1} \
CONFIG.M02_HAS_REGSLICE {1} \
CONFIG.M03_HAS_REGSLICE {1} \
CONFIG.M04_HAS_REGSLICE {1} \
CONFIG.M05_HAS_REGSLICE {1} \
CONFIG.M06_HAS_REGSLICE {1} \
CONFIG.M07_HAS_REGSLICE {1} \
CONFIG.M08_HAS_REGSLICE {1} \
CONFIG.M09_HAS_REGSLICE {1} \
CONFIG.M10_HAS_REGSLICE {1} \
CONFIG.NUM_MI {11} \
CONFIG.NUM_SI {1} \
CONFIG.S00_HAS_REGSLICE {1} \
CONFIG.STRATEGY {2} \
 ] $axi_ic_processing_system7_0_M_AXI_GP1

  # Create instance: axi_ic_processing_system7_0_S_AXI_HP1, and set properties
  set axi_ic_processing_system7_0_S_AXI_HP1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 axi_ic_processing_system7_0_S_AXI_HP1 ]
  set_property -dict [ list \
CONFIG.M00_HAS_DATA_FIFO {2} \
CONFIG.M00_HAS_REGSLICE {1} \
CONFIG.NUM_MI {1} \
CONFIG.NUM_SI {2} \
CONFIG.S00_HAS_DATA_FIFO {2} \
CONFIG.S00_HAS_REGSLICE {1} \
CONFIG.S01_HAS_DATA_FIFO {2} \
CONFIG.S01_HAS_REGSLICE {1} \
CONFIG.STRATEGY {2} \
 ] $axi_ic_processing_system7_0_S_AXI_HP1

  # Create instance: axi_ic_processing_system7_0_S_AXI_HP2, and set properties
  set axi_ic_processing_system7_0_S_AXI_HP2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 axi_ic_processing_system7_0_S_AXI_HP2 ]
  set_property -dict [ list \
CONFIG.M00_HAS_DATA_FIFO {2} \
CONFIG.M00_HAS_REGSLICE {1} \
CONFIG.NUM_MI {1} \
CONFIG.NUM_SI {1} \
CONFIG.S00_HAS_DATA_FIFO {2} \
CONFIG.S00_HAS_REGSLICE {1} \
CONFIG.STRATEGY {0} \
 ] $axi_ic_processing_system7_0_S_AXI_HP2

  # Create instance: axi_interconnect_0, and set properties
  set axi_interconnect_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 axi_interconnect_0 ]
  set_property -dict [ list \
CONFIG.M00_HAS_REGSLICE {1} \
CONFIG.NUM_MI {1} \
CONFIG.NUM_SI {2} \
CONFIG.S00_HAS_DATA_FIFO {2} \
CONFIG.S00_HAS_REGSLICE {1} \
CONFIG.S01_HAS_DATA_FIFO {2} \
CONFIG.S01_HAS_REGSLICE {1} \
 ] $axi_interconnect_0

  # Create instance: axi_vdma_0, and set properties
  set axi_vdma_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_vdma:6.2 axi_vdma_0 ]
  set_property -dict [ list \
CONFIG.c_m_axi_s2mm_data_width {64} \
CONFIG.c_m_axis_mm2s_tdata_width {16} \
CONFIG.c_mm2s_linebuffer_depth {4096} \
CONFIG.c_mm2s_max_burst_length {64} \
CONFIG.c_num_fstores {8} \
CONFIG.c_s2mm_linebuffer_depth {4096} \
CONFIG.c_s2mm_max_burst_length {64} \
 ] $axi_vdma_0

  # Create instance: clk_wiz_1, and set properties
  set clk_wiz_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:clk_wiz:5.2 clk_wiz_1 ]
  set_property -dict [ list \
CONFIG.CLKOUT1_JITTER {196.394} \
CONFIG.CLKOUT1_PHASE_ERROR {155.997} \
CONFIG.CLKOUT1_REQUESTED_OUT_FREQ {150.000} \
CONFIG.CLKOUT2_JITTER {206.371} \
CONFIG.CLKOUT2_PHASE_ERROR {155.997} \
CONFIG.CLKOUT2_REQUESTED_OUT_FREQ {120.000} \
CONFIG.CLKOUT2_USED {true} \
CONFIG.CLKOUT3_JITTER {214.854} \
CONFIG.CLKOUT3_PHASE_ERROR {155.997} \
CONFIG.CLKOUT3_USED {true} \
CONFIG.CLKOUT4_JITTER {228.642} \
CONFIG.CLKOUT4_PHASE_ERROR {155.997} \
CONFIG.CLKOUT4_REQUESTED_OUT_FREQ {75.000} \
CONFIG.CLKOUT4_USED {true} \
CONFIG.MMCM_CLKFBOUT_MULT_F {12.000} \
CONFIG.MMCM_CLKOUT0_DIVIDE_F {4.000} \
CONFIG.MMCM_CLKOUT1_DIVIDE {5} \
CONFIG.MMCM_CLKOUT2_DIVIDE {6} \
CONFIG.MMCM_CLKOUT3_DIVIDE {8} \
CONFIG.MMCM_DIVCLK_DIVIDE {1} \
CONFIG.NUM_OUT_CLKS {4} \
CONFIG.RESET_TYPE {ACTIVE_LOW} \
 ] $clk_wiz_1

  # Create instance: clkgen_variable, and set properties
  set clkgen_variable [ create_bd_cell -type ip -vlnv xilinx.com:ip:clk_wiz:5.2 clkgen_variable ]
  set_property -dict [ list \
CONFIG.CLKOUT1_JITTER {221.353} \
CONFIG.CLKOUT1_PHASE_ERROR {245.344} \
CONFIG.CLKOUT1_REQUESTED_OUT_FREQ {148.500} \
CONFIG.MMCM_CLKFBOUT_MULT_F {37.125} \
CONFIG.MMCM_CLKOUT0_DIVIDE_F {6.250} \
CONFIG.MMCM_DIVCLK_DIVIDE {2} \
CONFIG.USE_DYN_RECONFIG {true} \
 ] $clkgen_variable

  # Create instance: combo_image_0, and set properties
  set combo_image_0 [ create_bd_cell -type ip -vlnv xilinx.com:hls:combo_image:1.0 combo_image_0 ]

  # Create instance: combo_image_0_if, and set properties
  set combo_image_0_if [ create_bd_cell -type ip -vlnv xilinx.com:ip:axis_accelerator_adapter:2.1 combo_image_0_if ]
  set_property -dict [ list \
CONFIG.C_AP_IARG_0_DIM_1 {1024} \
CONFIG.C_AP_IARG_0_DWIDTH {8} \
CONFIG.C_AP_IARG_0_TYPE {1} \
CONFIG.C_AP_IARG_0_WIDTH {8} \
CONFIG.C_AP_IARG_1_DIM_1 {1024} \
CONFIG.C_AP_IARG_1_DWIDTH {16} \
CONFIG.C_AP_IARG_1_TYPE {1} \
CONFIG.C_AP_IARG_1_WIDTH {16} \
CONFIG.C_AP_OARG_0_DIM_1 {1024} \
CONFIG.C_AP_OARG_0_DWIDTH {16} \
CONFIG.C_AP_OARG_0_TYPE {1} \
CONFIG.C_AP_OARG_0_WIDTH {16} \
CONFIG.C_INPUT_SCALAR_0_WIDTH {8} \
CONFIG.C_M_AXIS_HAS_TKEEP {1} \
CONFIG.C_M_AXIS_HAS_TSTRB {1} \
CONFIG.C_M_AXIS_TDATA_WIDTH {64} \
CONFIG.C_N_INPUT_ARGS {2} \
CONFIG.C_N_INPUT_SCALARS {1} \
CONFIG.C_N_OUTPUT_ARGS {1} \
CONFIG.C_S_AXIS_TDATA_WIDTH {64} \
 ] $combo_image_0_if

  # Create instance: diff_image_0, and set properties
  set diff_image_0 [ create_bd_cell -type ip -vlnv xilinx.com:hls:diff_image:1.0 diff_image_0 ]

  # Create instance: diff_image_0_if, and set properties
  set diff_image_0_if [ create_bd_cell -type ip -vlnv xilinx.com:ip:axis_accelerator_adapter:2.1 diff_image_0_if ]
  set_property -dict [ list \
CONFIG.C_AP_IARG_0_DIM_1 {1024} \
CONFIG.C_AP_IARG_0_DWIDTH {8} \
CONFIG.C_AP_IARG_0_TYPE {1} \
CONFIG.C_AP_IARG_0_WIDTH {8} \
CONFIG.C_AP_IARG_1_DIM_1 {1024} \
CONFIG.C_AP_IARG_1_DWIDTH {8} \
CONFIG.C_AP_IARG_1_TYPE {1} \
CONFIG.C_AP_IARG_1_WIDTH {8} \
CONFIG.C_AP_IARG_2_DIM_1 {1024} \
CONFIG.C_AP_IARG_2_DWIDTH {16} \
CONFIG.C_AP_IARG_2_TYPE {1} \
CONFIG.C_AP_IARG_2_WIDTH {16} \
CONFIG.C_AP_OARG_0_DIM_1 {1024} \
CONFIG.C_AP_OARG_0_DWIDTH {16} \
CONFIG.C_AP_OARG_0_TYPE {1} \
CONFIG.C_AP_OARG_0_WIDTH {16} \
CONFIG.C_AP_OARG_1_DIM_1 {1024} \
CONFIG.C_AP_OARG_1_DWIDTH {8} \
CONFIG.C_AP_OARG_1_TYPE {1} \
CONFIG.C_AP_OARG_1_WIDTH {8} \
CONFIG.C_M_AXIS_HAS_TKEEP {1} \
CONFIG.C_M_AXIS_HAS_TSTRB {1} \
CONFIG.C_M_AXIS_TDATA_WIDTH {64} \
CONFIG.C_N_INPUT_ARGS {3} \
CONFIG.C_N_OUTPUT_ARGS {2} \
CONFIG.C_S_AXIS_TDATA_WIDTH {64} \
 ] $diff_image_0_if

  # Create instance: dm_0, and set properties
  set dm_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dma:7.1 dm_0 ]
  set_property -dict [ list \
CONFIG.c_dlytmr_resolution {1250} \
CONFIG.c_include_mm2s {1} \
CONFIG.c_include_mm2s_dre {1} \
CONFIG.c_include_mm2s_sf {1} \
CONFIG.c_include_s2mm {0} \
CONFIG.c_include_sg {0} \
CONFIG.c_m_axi_mm2s_data_width {64} \
CONFIG.c_m_axis_mm2s_tdata_width {64} \
CONFIG.c_mm2s_burst_size {64} \
CONFIG.c_sg_length_width {23} \
 ] $dm_0

  # Create instance: dm_1, and set properties
  set dm_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dma:7.1 dm_1 ]
  set_property -dict [ list \
CONFIG.c_dlytmr_resolution {1250} \
CONFIG.c_include_mm2s {1} \
CONFIG.c_include_mm2s_dre {1} \
CONFIG.c_include_mm2s_sf {1} \
CONFIG.c_include_s2mm {0} \
CONFIG.c_include_sg {0} \
CONFIG.c_m_axi_mm2s_data_width {64} \
CONFIG.c_m_axis_mm2s_tdata_width {64} \
CONFIG.c_mm2s_burst_size {64} \
CONFIG.c_sg_length_width {23} \
 ] $dm_1

  # Create instance: dm_2, and set properties
  set dm_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dma:7.1 dm_2 ]
  set_property -dict [ list \
CONFIG.c_dlytmr_resolution {1250} \
CONFIG.c_include_mm2s {0} \
CONFIG.c_include_s2mm {1} \
CONFIG.c_include_s2mm_dre {1} \
CONFIG.c_include_s2mm_sf {1} \
CONFIG.c_include_sg {0} \
CONFIG.c_m_axi_s2mm_data_width {64} \
CONFIG.c_s2mm_burst_size {64} \
CONFIG.c_s_axis_s2mm_tdata_width {64} \
CONFIG.c_sg_length_width {23} \
 ] $dm_2

  # Create instance: ext_0, and set properties
  set ext_0 [ create_bd_cell -type ip -vlnv xilinx.com:hls:ext:1.0 ext_0 ]

  # Create instance: ext_0_if, and set properties
  set ext_0_if [ create_bd_cell -type ip -vlnv xilinx.com:ip:axis_accelerator_adapter:2.1 ext_0_if ]
  set_property -dict [ list \
CONFIG.C_AP_IARG_0_DIM_1 {1024} \
CONFIG.C_AP_IARG_0_DWIDTH {16} \
CONFIG.C_AP_IARG_0_TYPE {1} \
CONFIG.C_AP_IARG_0_WIDTH {16} \
CONFIG.C_AP_OARG_0_DIM_1 {1024} \
CONFIG.C_AP_OARG_0_DWIDTH {16} \
CONFIG.C_AP_OARG_0_TYPE {1} \
CONFIG.C_AP_OARG_0_WIDTH {16} \
CONFIG.C_M_AXIS_HAS_TKEEP {1} \
CONFIG.C_M_AXIS_HAS_TSTRB {1} \
CONFIG.C_M_AXIS_TDATA_WIDTH {64} \
CONFIG.C_N_INPUT_ARGS {1} \
CONFIG.C_N_OUTPUT_ARGS {1} \
CONFIG.C_S_AXIS_TDATA_WIDTH {64} \
 ] $ext_0_if

  # Create instance: fmc2_imageon_iic, and set properties
  set fmc2_imageon_iic [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_iic:2.0 fmc2_imageon_iic ]
  set_property -dict [ list \
CONFIG.C_SCL_INERTIAL_DELAY {5} \
CONFIG.C_SDA_INERTIAL_DELAY {5} \
 ] $fmc2_imageon_iic

  # Create instance: imageon_hdmi_in
  create_hier_cell_imageon_hdmi_in [current_bd_instance .] imageon_hdmi_in

  # Create instance: imageon_hdmi_out
  create_hier_cell_imageon_hdmi_out [current_bd_instance .] imageon_hdmi_out

  # Create instance: median_char_filter_pass_0, and set properties
  set median_char_filter_pass_0 [ create_bd_cell -type ip -vlnv xilinx.com:hls:median_char_filter_pass:1.0 median_char_filter_pass_0 ]

  # Create instance: median_char_filter_pass_0_if, and set properties
  set median_char_filter_pass_0_if [ create_bd_cell -type ip -vlnv xilinx.com:ip:axis_accelerator_adapter:2.1 median_char_filter_pass_0_if ]
  set_property -dict [ list \
CONFIG.C_AP_IARG_0_DIM_1 {1024} \
CONFIG.C_AP_IARG_0_DWIDTH {8} \
CONFIG.C_AP_IARG_0_TYPE {1} \
CONFIG.C_AP_IARG_0_WIDTH {8} \
CONFIG.C_AP_IARG_1_DIM_1 {1024} \
CONFIG.C_AP_IARG_1_DWIDTH {16} \
CONFIG.C_AP_IARG_1_TYPE {1} \
CONFIG.C_AP_IARG_1_WIDTH {16} \
CONFIG.C_AP_OARG_0_DIM_1 {1024} \
CONFIG.C_AP_OARG_0_DWIDTH {8} \
CONFIG.C_AP_OARG_0_TYPE {1} \
CONFIG.C_AP_OARG_0_WIDTH {8} \
CONFIG.C_AP_OARG_1_DIM_1 {1024} \
CONFIG.C_AP_OARG_1_DWIDTH {16} \
CONFIG.C_AP_OARG_1_TYPE {1} \
CONFIG.C_AP_OARG_1_WIDTH {16} \
CONFIG.C_INPUT_SCALAR_0_WIDTH {8} \
CONFIG.C_M_AXIS_HAS_TKEEP {1} \
CONFIG.C_M_AXIS_HAS_TSTRB {1} \
CONFIG.C_M_AXIS_TDATA_WIDTH {64} \
CONFIG.C_N_INPUT_ARGS {2} \
CONFIG.C_N_INPUT_SCALARS {1} \
CONFIG.C_N_OUTPUT_ARGS {2} \
CONFIG.C_S_AXIS_TDATA_WIDTH {64} \
 ] $median_char_filter_pass_0_if

  # Create instance: pad_0, and set properties
  set pad_0 [ create_bd_cell -type ip -vlnv xilinx.com:hls:pad:1.0 pad_0 ]

  # Create instance: pad_0_if, and set properties
  set pad_0_if [ create_bd_cell -type ip -vlnv xilinx.com:ip:axis_accelerator_adapter:2.1 pad_0_if ]
  set_property -dict [ list \
CONFIG.C_AP_IARG_0_DIM_1 {1024} \
CONFIG.C_AP_IARG_0_DWIDTH {16} \
CONFIG.C_AP_IARG_0_TYPE {1} \
CONFIG.C_AP_IARG_0_WIDTH {16} \
CONFIG.C_AP_OARG_0_DIM_1 {1024} \
CONFIG.C_AP_OARG_0_DWIDTH {16} \
CONFIG.C_AP_OARG_0_TYPE {1} \
CONFIG.C_AP_OARG_0_WIDTH {16} \
CONFIG.C_M_AXIS_HAS_TKEEP {1} \
CONFIG.C_M_AXIS_HAS_TSTRB {1} \
CONFIG.C_M_AXIS_TDATA_WIDTH {64} \
CONFIG.C_N_INPUT_ARGS {1} \
CONFIG.C_N_OUTPUT_ARGS {1} \
CONFIG.C_S_AXIS_TDATA_WIDTH {64} \
 ] $pad_0_if

  # Create instance: pad_1, and set properties
  set pad_1 [ create_bd_cell -type ip -vlnv xilinx.com:hls:pad:1.0 pad_1 ]

  # Create instance: pad_1_if, and set properties
  set pad_1_if [ create_bd_cell -type ip -vlnv xilinx.com:ip:axis_accelerator_adapter:2.1 pad_1_if ]
  set_property -dict [ list \
CONFIG.C_AP_IARG_0_DIM_1 {1024} \
CONFIG.C_AP_IARG_0_DWIDTH {16} \
CONFIG.C_AP_IARG_0_TYPE {1} \
CONFIG.C_AP_IARG_0_WIDTH {16} \
CONFIG.C_AP_OARG_0_DIM_1 {1024} \
CONFIG.C_AP_OARG_0_DWIDTH {16} \
CONFIG.C_AP_OARG_0_TYPE {1} \
CONFIG.C_AP_OARG_0_WIDTH {16} \
CONFIG.C_M_AXIS_HAS_TKEEP {1} \
CONFIG.C_M_AXIS_HAS_TSTRB {1} \
CONFIG.C_M_AXIS_TDATA_WIDTH {64} \
CONFIG.C_N_INPUT_ARGS {1} \
CONFIG.C_N_OUTPUT_ARGS {1} \
CONFIG.C_S_AXIS_TDATA_WIDTH {64} \
 ] $pad_1_if

  # Create instance: proc_sys_reset_100MHz, and set properties
  set proc_sys_reset_100MHz [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_100MHz ]

  # Create instance: proc_sys_reset_120MHz, and set properties
  set proc_sys_reset_120MHz [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_120MHz ]

  # Create instance: proc_sys_reset_150MHz, and set properties
  set proc_sys_reset_150MHz [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_150MHz ]

  # Create instance: proc_sys_reset_50MHz, and set properties
  set proc_sys_reset_50MHz [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_50MHz ]

  # Create instance: proc_sys_reset_75MHz, and set properties
  set proc_sys_reset_75MHz [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_75MHz ]

  # Create instance: processing_system7_0, and set properties
  set processing_system7_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:processing_system7:5.5 processing_system7_0 ]
  set_property -dict [ list \
CONFIG.PCW_ACT_APU_PERIPHERAL_FREQMHZ {666.666687} \
CONFIG.PCW_ACT_CAN0_PERIPHERAL_FREQMHZ {23.8095} \
CONFIG.PCW_ACT_CAN1_PERIPHERAL_FREQMHZ {23.8095} \
CONFIG.PCW_ACT_CAN_PERIPHERAL_FREQMHZ {10.000000} \
CONFIG.PCW_ACT_DCI_PERIPHERAL_FREQMHZ {10.158731} \
CONFIG.PCW_ACT_ENET0_PERIPHERAL_FREQMHZ {125.000000} \
CONFIG.PCW_ACT_ENET1_PERIPHERAL_FREQMHZ {10.000000} \
CONFIG.PCW_ACT_FPGA0_PERIPHERAL_FREQMHZ {50.000000} \
CONFIG.PCW_ACT_FPGA1_PERIPHERAL_FREQMHZ {100.000000} \
CONFIG.PCW_ACT_FPGA2_PERIPHERAL_FREQMHZ {50.000000} \
CONFIG.PCW_ACT_FPGA3_PERIPHERAL_FREQMHZ {50.000000} \
CONFIG.PCW_ACT_I2C_PERIPHERAL_FREQMHZ {50} \
CONFIG.PCW_ACT_PCAP_PERIPHERAL_FREQMHZ {200.000000} \
CONFIG.PCW_ACT_QSPI_PERIPHERAL_FREQMHZ {200.000000} \
CONFIG.PCW_ACT_SDIO_PERIPHERAL_FREQMHZ {100.000000} \
CONFIG.PCW_ACT_SMC_PERIPHERAL_FREQMHZ {10.000000} \
CONFIG.PCW_ACT_SPI_PERIPHERAL_FREQMHZ {10.000000} \
CONFIG.PCW_ACT_TPIU_PERIPHERAL_FREQMHZ {200.000000} \
CONFIG.PCW_ACT_TTC0_CLK0_PERIPHERAL_FREQMHZ {111.111115} \
CONFIG.PCW_ACT_TTC0_CLK1_PERIPHERAL_FREQMHZ {111.111115} \
CONFIG.PCW_ACT_TTC0_CLK2_PERIPHERAL_FREQMHZ {111.111115} \
CONFIG.PCW_ACT_TTC1_CLK0_PERIPHERAL_FREQMHZ {111.111115} \
CONFIG.PCW_ACT_TTC1_CLK1_PERIPHERAL_FREQMHZ {111.111115} \
CONFIG.PCW_ACT_TTC1_CLK2_PERIPHERAL_FREQMHZ {111.111115} \
CONFIG.PCW_ACT_TTC_PERIPHERAL_FREQMHZ {50} \
CONFIG.PCW_ACT_UART_PERIPHERAL_FREQMHZ {100.000000} \
CONFIG.PCW_ACT_USB0_PERIPHERAL_FREQMHZ {60} \
CONFIG.PCW_ACT_USB1_PERIPHERAL_FREQMHZ {60} \
CONFIG.PCW_ACT_WDT_PERIPHERAL_FREQMHZ {111.111115} \
CONFIG.PCW_APU_CLK_RATIO_ENABLE {6:2:1} \
CONFIG.PCW_APU_PERIPHERAL_FREQMHZ {666.666666} \
CONFIG.PCW_ARMPLL_CTRL_FBDIV {40} \
CONFIG.PCW_CAN0_BASEADDR {0xE0008000} \
CONFIG.PCW_CAN0_GRP_CLK_ENABLE {0} \
CONFIG.PCW_CAN0_HIGHADDR {0xE0008FFF} \
CONFIG.PCW_CAN0_PERIPHERAL_CLKSRC {External} \
CONFIG.PCW_CAN0_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_CAN0_PERIPHERAL_FREQMHZ {-1} \
CONFIG.PCW_CAN1_BASEADDR {0xE0009000} \
CONFIG.PCW_CAN1_GRP_CLK_ENABLE {0} \
CONFIG.PCW_CAN1_HIGHADDR {0xE0009FFF} \
CONFIG.PCW_CAN1_PERIPHERAL_CLKSRC {External} \
CONFIG.PCW_CAN1_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_CAN1_PERIPHERAL_FREQMHZ {-1} \
CONFIG.PCW_CAN_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_CAN_PERIPHERAL_DIVISOR0 {1} \
CONFIG.PCW_CAN_PERIPHERAL_DIVISOR1 {1} \
CONFIG.PCW_CAN_PERIPHERAL_FREQMHZ {100} \
CONFIG.PCW_CAN_PERIPHERAL_VALID {0} \
CONFIG.PCW_CLK0_FREQ {50000000} \
CONFIG.PCW_CLK1_FREQ {100000000} \
CONFIG.PCW_CLK2_FREQ {50000000} \
CONFIG.PCW_CLK3_FREQ {50000000} \
CONFIG.PCW_CORE0_FIQ_INTR {0} \
CONFIG.PCW_CORE0_IRQ_INTR {0} \
CONFIG.PCW_CORE1_FIQ_INTR {0} \
CONFIG.PCW_CORE1_IRQ_INTR {0} \
CONFIG.PCW_CPU_CPU_6X4X_MAX_RANGE {667} \
CONFIG.PCW_CPU_CPU_PLL_FREQMHZ {1333.333} \
CONFIG.PCW_CPU_PERIPHERAL_CLKSRC {ARM PLL} \
CONFIG.PCW_CPU_PERIPHERAL_DIVISOR0 {2} \
CONFIG.PCW_CRYSTAL_PERIPHERAL_FREQMHZ {33.333333} \
CONFIG.PCW_DCI_PERIPHERAL_CLKSRC {DDR PLL} \
CONFIG.PCW_DCI_PERIPHERAL_DIVISOR0 {35} \
CONFIG.PCW_DCI_PERIPHERAL_DIVISOR1 {3} \
CONFIG.PCW_DCI_PERIPHERAL_FREQMHZ {10.159} \
CONFIG.PCW_DDRPLL_CTRL_FBDIV {32} \
CONFIG.PCW_DDR_DDR_PLL_FREQMHZ {1066.667} \
CONFIG.PCW_DDR_HPRLPR_QUEUE_PARTITION {HPR(0)/LPR(32)} \
CONFIG.PCW_DDR_HPR_TO_CRITICAL_PRIORITY_LEVEL {15} \
CONFIG.PCW_DDR_LPR_TO_CRITICAL_PRIORITY_LEVEL {2} \
CONFIG.PCW_DDR_PERIPHERAL_CLKSRC {DDR PLL} \
CONFIG.PCW_DDR_PERIPHERAL_DIVISOR0 {2} \
CONFIG.PCW_DDR_PORT0_HPR_ENABLE {0} \
CONFIG.PCW_DDR_PORT1_HPR_ENABLE {0} \
CONFIG.PCW_DDR_PORT2_HPR_ENABLE {0} \
CONFIG.PCW_DDR_PORT3_HPR_ENABLE {0} \
CONFIG.PCW_DDR_RAM_BASEADDR {0x00100000} \
CONFIG.PCW_DDR_RAM_HIGHADDR {0x3FFFFFFF} \
CONFIG.PCW_DDR_WRITE_TO_CRITICAL_PRIORITY_LEVEL {2} \
CONFIG.PCW_DM_WIDTH {4} \
CONFIG.PCW_DQS_WIDTH {4} \
CONFIG.PCW_DQ_WIDTH {32} \
CONFIG.PCW_ENET0_BASEADDR {0xE000B000} \
CONFIG.PCW_ENET0_ENET0_IO {MIO 16 .. 27} \
CONFIG.PCW_ENET0_GRP_MDIO_ENABLE {1} \
CONFIG.PCW_ENET0_GRP_MDIO_IO {MIO 52 .. 53} \
CONFIG.PCW_ENET0_HIGHADDR {0xE000BFFF} \
CONFIG.PCW_ENET0_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_ENET0_PERIPHERAL_DIVISOR0 {8} \
CONFIG.PCW_ENET0_PERIPHERAL_DIVISOR1 {1} \
CONFIG.PCW_ENET0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_ENET0_PERIPHERAL_FREQMHZ {1000 Mbps} \
CONFIG.PCW_ENET0_RESET_ENABLE {1} \
CONFIG.PCW_ENET0_RESET_IO {MIO 50} \
CONFIG.PCW_ENET1_BASEADDR {0xE000C000} \
CONFIG.PCW_ENET1_GRP_MDIO_ENABLE {0} \
CONFIG.PCW_ENET1_HIGHADDR {0xE000CFFF} \
CONFIG.PCW_ENET1_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_ENET1_PERIPHERAL_DIVISOR0 {1} \
CONFIG.PCW_ENET1_PERIPHERAL_DIVISOR1 {1} \
CONFIG.PCW_ENET1_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_ENET1_PERIPHERAL_FREQMHZ {1000 Mbps} \
CONFIG.PCW_ENET1_RESET_ENABLE {0} \
CONFIG.PCW_ENET_RESET_ENABLE {1} \
CONFIG.PCW_ENET_RESET_POLARITY {Active Low} \
CONFIG.PCW_ENET_RESET_SELECT {Share reset pin} \
CONFIG.PCW_EN_4K_TIMER {0} \
CONFIG.PCW_EN_CAN0 {0} \
CONFIG.PCW_EN_CAN1 {0} \
CONFIG.PCW_EN_CLK0_PORT {1} \
CONFIG.PCW_EN_CLK1_PORT {0} \
CONFIG.PCW_EN_CLK2_PORT {0} \
CONFIG.PCW_EN_CLK3_PORT {0} \
CONFIG.PCW_EN_CLKTRIG0_PORT {0} \
CONFIG.PCW_EN_CLKTRIG1_PORT {0} \
CONFIG.PCW_EN_CLKTRIG2_PORT {0} \
CONFIG.PCW_EN_CLKTRIG3_PORT {0} \
CONFIG.PCW_EN_DDR {1} \
CONFIG.PCW_EN_EMIO_CAN0 {0} \
CONFIG.PCW_EN_EMIO_CAN1 {0} \
CONFIG.PCW_EN_EMIO_CD_SDIO0 {0} \
CONFIG.PCW_EN_EMIO_CD_SDIO1 {0} \
CONFIG.PCW_EN_EMIO_ENET0 {0} \
CONFIG.PCW_EN_EMIO_ENET1 {0} \
CONFIG.PCW_EN_EMIO_GPIO {0} \
CONFIG.PCW_EN_EMIO_I2C0 {0} \
CONFIG.PCW_EN_EMIO_I2C1 {0} \
CONFIG.PCW_EN_EMIO_MODEM_UART0 {0} \
CONFIG.PCW_EN_EMIO_MODEM_UART1 {0} \
CONFIG.PCW_EN_EMIO_PJTAG {0} \
CONFIG.PCW_EN_EMIO_SDIO0 {0} \
CONFIG.PCW_EN_EMIO_SDIO1 {0} \
CONFIG.PCW_EN_EMIO_SPI0 {0} \
CONFIG.PCW_EN_EMIO_SPI1 {0} \
CONFIG.PCW_EN_EMIO_SRAM_INT {0} \
CONFIG.PCW_EN_EMIO_TRACE {0} \
CONFIG.PCW_EN_EMIO_TTC0 {1} \
CONFIG.PCW_EN_EMIO_TTC1 {1} \
CONFIG.PCW_EN_EMIO_UART0 {0} \
CONFIG.PCW_EN_EMIO_UART1 {0} \
CONFIG.PCW_EN_EMIO_WDT {0} \
CONFIG.PCW_EN_EMIO_WP_SDIO0 {0} \
CONFIG.PCW_EN_EMIO_WP_SDIO1 {0} \
CONFIG.PCW_EN_ENET0 {1} \
CONFIG.PCW_EN_ENET1 {0} \
CONFIG.PCW_EN_GPIO {1} \
CONFIG.PCW_EN_I2C0 {1} \
CONFIG.PCW_EN_I2C1 {1} \
CONFIG.PCW_EN_MODEM_UART0 {0} \
CONFIG.PCW_EN_MODEM_UART1 {0} \
CONFIG.PCW_EN_PJTAG {0} \
CONFIG.PCW_EN_QSPI {1} \
CONFIG.PCW_EN_RST0_PORT {1} \
CONFIG.PCW_EN_RST1_PORT {0} \
CONFIG.PCW_EN_RST2_PORT {0} \
CONFIG.PCW_EN_RST3_PORT {0} \
CONFIG.PCW_EN_SDIO0 {1} \
CONFIG.PCW_EN_SDIO1 {0} \
CONFIG.PCW_EN_SMC {0} \
CONFIG.PCW_EN_SPI0 {0} \
CONFIG.PCW_EN_SPI1 {0} \
CONFIG.PCW_EN_TRACE {0} \
CONFIG.PCW_EN_TTC0 {1} \
CONFIG.PCW_EN_TTC1 {1} \
CONFIG.PCW_EN_UART0 {1} \
CONFIG.PCW_EN_UART1 {1} \
CONFIG.PCW_EN_USB0 {1} \
CONFIG.PCW_EN_USB1 {0} \
CONFIG.PCW_EN_WDT {0} \
CONFIG.PCW_FCLK0_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_FCLK0_PERIPHERAL_DIVISOR0 {20} \
CONFIG.PCW_FCLK0_PERIPHERAL_DIVISOR1 {1} \
CONFIG.PCW_FCLK1_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_FCLK1_PERIPHERAL_DIVISOR0 {10} \
CONFIG.PCW_FCLK1_PERIPHERAL_DIVISOR1 {1} \
CONFIG.PCW_FCLK2_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_FCLK2_PERIPHERAL_DIVISOR0 {20} \
CONFIG.PCW_FCLK2_PERIPHERAL_DIVISOR1 {1} \
CONFIG.PCW_FCLK3_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_FCLK3_PERIPHERAL_DIVISOR0 {20} \
CONFIG.PCW_FCLK3_PERIPHERAL_DIVISOR1 {1} \
CONFIG.PCW_FCLK_CLK0_BUF {true} \
CONFIG.PCW_FCLK_CLK1_BUF {false} \
CONFIG.PCW_FCLK_CLK2_BUF {false} \
CONFIG.PCW_FCLK_CLK3_BUF {false} \
CONFIG.PCW_FPGA0_PERIPHERAL_FREQMHZ {50} \
CONFIG.PCW_FPGA1_PERIPHERAL_FREQMHZ {100} \
CONFIG.PCW_FPGA2_PERIPHERAL_FREQMHZ {50} \
CONFIG.PCW_FPGA3_PERIPHERAL_FREQMHZ {50} \
CONFIG.PCW_FPGA_FCLK0_ENABLE {1} \
CONFIG.PCW_FPGA_FCLK1_ENABLE {0} \
CONFIG.PCW_FPGA_FCLK2_ENABLE {0} \
CONFIG.PCW_FPGA_FCLK3_ENABLE {0} \
CONFIG.PCW_GPIO_BASEADDR {0xE000A000} \
CONFIG.PCW_GPIO_EMIO_GPIO_ENABLE {0} \
CONFIG.PCW_GPIO_EMIO_GPIO_WIDTH {64} \
CONFIG.PCW_GPIO_HIGHADDR {0xE000AFFF} \
CONFIG.PCW_GPIO_MIO_GPIO_ENABLE {1} \
CONFIG.PCW_GPIO_MIO_GPIO_IO {MIO} \
CONFIG.PCW_GPIO_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_I2C0_BASEADDR {0xE0004000} \
CONFIG.PCW_I2C0_GRP_INT_ENABLE {0} \
CONFIG.PCW_I2C0_HIGHADDR {0xE0004FFF} \
CONFIG.PCW_I2C0_I2C0_IO {MIO 10 .. 11} \
CONFIG.PCW_I2C0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_I2C0_RESET_ENABLE {0} \
CONFIG.PCW_I2C1_BASEADDR {0xE0005000} \
CONFIG.PCW_I2C1_GRP_INT_ENABLE {1} \
CONFIG.PCW_I2C1_GRP_INT_IO {EMIO} \
CONFIG.PCW_I2C1_HIGHADDR {0xE0005FFF} \
CONFIG.PCW_I2C1_I2C1_IO {MIO 48 .. 49} \
CONFIG.PCW_I2C1_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_I2C1_RESET_ENABLE {0} \
CONFIG.PCW_I2C_PERIPHERAL_FREQMHZ {111.111115} \
CONFIG.PCW_I2C_RESET_ENABLE {0} \
CONFIG.PCW_I2C_RESET_POLARITY {Active Low} \
CONFIG.PCW_IMPORT_BOARD_PRESET {None} \
CONFIG.PCW_INCLUDE_ACP_TRANS_CHECK {0} \
CONFIG.PCW_INCLUDE_TRACE_BUFFER {0} \
CONFIG.PCW_IOPLL_CTRL_FBDIV {30} \
CONFIG.PCW_IO_IO_PLL_FREQMHZ {1000.000} \
CONFIG.PCW_IRQ_F2P_INTR {1} \
CONFIG.PCW_IRQ_F2P_MODE {DIRECT} \
CONFIG.PCW_MIO_0_DIRECTION {inout} \
CONFIG.PCW_MIO_0_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_0_PULLUP {enabled} \
CONFIG.PCW_MIO_0_SLEW {slow} \
CONFIG.PCW_MIO_10_DIRECTION {inout} \
CONFIG.PCW_MIO_10_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_10_PULLUP {enabled} \
CONFIG.PCW_MIO_10_SLEW {slow} \
CONFIG.PCW_MIO_11_DIRECTION {inout} \
CONFIG.PCW_MIO_11_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_11_PULLUP {enabled} \
CONFIG.PCW_MIO_11_SLEW {slow} \
CONFIG.PCW_MIO_12_DIRECTION {out} \
CONFIG.PCW_MIO_12_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_12_PULLUP {enabled} \
CONFIG.PCW_MIO_12_SLEW {slow} \
CONFIG.PCW_MIO_13_DIRECTION {in} \
CONFIG.PCW_MIO_13_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_13_PULLUP {enabled} \
CONFIG.PCW_MIO_13_SLEW {slow} \
CONFIG.PCW_MIO_14_DIRECTION {in} \
CONFIG.PCW_MIO_14_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_14_PULLUP {enabled} \
CONFIG.PCW_MIO_14_SLEW {slow} \
CONFIG.PCW_MIO_15_DIRECTION {out} \
CONFIG.PCW_MIO_15_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_15_PULLUP {enabled} \
CONFIG.PCW_MIO_15_SLEW {slow} \
CONFIG.PCW_MIO_16_DIRECTION {out} \
CONFIG.PCW_MIO_16_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_16_PULLUP {enabled} \
CONFIG.PCW_MIO_16_SLEW {slow} \
CONFIG.PCW_MIO_17_DIRECTION {out} \
CONFIG.PCW_MIO_17_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_17_PULLUP {enabled} \
CONFIG.PCW_MIO_17_SLEW {slow} \
CONFIG.PCW_MIO_18_DIRECTION {out} \
CONFIG.PCW_MIO_18_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_18_PULLUP {enabled} \
CONFIG.PCW_MIO_18_SLEW {slow} \
CONFIG.PCW_MIO_19_DIRECTION {out} \
CONFIG.PCW_MIO_19_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_19_PULLUP {enabled} \
CONFIG.PCW_MIO_19_SLEW {slow} \
CONFIG.PCW_MIO_1_DIRECTION {out} \
CONFIG.PCW_MIO_1_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_1_PULLUP {enabled} \
CONFIG.PCW_MIO_1_SLEW {slow} \
CONFIG.PCW_MIO_20_DIRECTION {out} \
CONFIG.PCW_MIO_20_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_20_PULLUP {enabled} \
CONFIG.PCW_MIO_20_SLEW {slow} \
CONFIG.PCW_MIO_21_DIRECTION {out} \
CONFIG.PCW_MIO_21_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_21_PULLUP {enabled} \
CONFIG.PCW_MIO_21_SLEW {slow} \
CONFIG.PCW_MIO_22_DIRECTION {in} \
CONFIG.PCW_MIO_22_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_22_PULLUP {enabled} \
CONFIG.PCW_MIO_22_SLEW {slow} \
CONFIG.PCW_MIO_23_DIRECTION {in} \
CONFIG.PCW_MIO_23_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_23_PULLUP {enabled} \
CONFIG.PCW_MIO_23_SLEW {slow} \
CONFIG.PCW_MIO_24_DIRECTION {in} \
CONFIG.PCW_MIO_24_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_24_PULLUP {enabled} \
CONFIG.PCW_MIO_24_SLEW {slow} \
CONFIG.PCW_MIO_25_DIRECTION {in} \
CONFIG.PCW_MIO_25_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_25_PULLUP {enabled} \
CONFIG.PCW_MIO_25_SLEW {slow} \
CONFIG.PCW_MIO_26_DIRECTION {in} \
CONFIG.PCW_MIO_26_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_26_PULLUP {enabled} \
CONFIG.PCW_MIO_26_SLEW {slow} \
CONFIG.PCW_MIO_27_DIRECTION {in} \
CONFIG.PCW_MIO_27_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_27_PULLUP {enabled} \
CONFIG.PCW_MIO_27_SLEW {slow} \
CONFIG.PCW_MIO_28_DIRECTION {inout} \
CONFIG.PCW_MIO_28_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_28_PULLUP {enabled} \
CONFIG.PCW_MIO_28_SLEW {slow} \
CONFIG.PCW_MIO_29_DIRECTION {in} \
CONFIG.PCW_MIO_29_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_29_PULLUP {enabled} \
CONFIG.PCW_MIO_29_SLEW {slow} \
CONFIG.PCW_MIO_2_DIRECTION {inout} \
CONFIG.PCW_MIO_2_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_2_PULLUP {disabled} \
CONFIG.PCW_MIO_2_SLEW {slow} \
CONFIG.PCW_MIO_30_DIRECTION {out} \
CONFIG.PCW_MIO_30_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_30_PULLUP {enabled} \
CONFIG.PCW_MIO_30_SLEW {slow} \
CONFIG.PCW_MIO_31_DIRECTION {in} \
CONFIG.PCW_MIO_31_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_31_PULLUP {enabled} \
CONFIG.PCW_MIO_31_SLEW {slow} \
CONFIG.PCW_MIO_32_DIRECTION {inout} \
CONFIG.PCW_MIO_32_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_32_PULLUP {enabled} \
CONFIG.PCW_MIO_32_SLEW {slow} \
CONFIG.PCW_MIO_33_DIRECTION {inout} \
CONFIG.PCW_MIO_33_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_33_PULLUP {enabled} \
CONFIG.PCW_MIO_33_SLEW {slow} \
CONFIG.PCW_MIO_34_DIRECTION {inout} \
CONFIG.PCW_MIO_34_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_34_PULLUP {enabled} \
CONFIG.PCW_MIO_34_SLEW {slow} \
CONFIG.PCW_MIO_35_DIRECTION {inout} \
CONFIG.PCW_MIO_35_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_35_PULLUP {enabled} \
CONFIG.PCW_MIO_35_SLEW {slow} \
CONFIG.PCW_MIO_36_DIRECTION {in} \
CONFIG.PCW_MIO_36_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_36_PULLUP {enabled} \
CONFIG.PCW_MIO_36_SLEW {slow} \
CONFIG.PCW_MIO_37_DIRECTION {inout} \
CONFIG.PCW_MIO_37_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_37_PULLUP {enabled} \
CONFIG.PCW_MIO_37_SLEW {slow} \
CONFIG.PCW_MIO_38_DIRECTION {inout} \
CONFIG.PCW_MIO_38_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_38_PULLUP {enabled} \
CONFIG.PCW_MIO_38_SLEW {slow} \
CONFIG.PCW_MIO_39_DIRECTION {inout} \
CONFIG.PCW_MIO_39_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_39_PULLUP {enabled} \
CONFIG.PCW_MIO_39_SLEW {slow} \
CONFIG.PCW_MIO_3_DIRECTION {inout} \
CONFIG.PCW_MIO_3_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_3_PULLUP {disabled} \
CONFIG.PCW_MIO_3_SLEW {slow} \
CONFIG.PCW_MIO_40_DIRECTION {inout} \
CONFIG.PCW_MIO_40_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_40_PULLUP {disabled} \
CONFIG.PCW_MIO_40_SLEW {slow} \
CONFIG.PCW_MIO_41_DIRECTION {inout} \
CONFIG.PCW_MIO_41_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_41_PULLUP {disabled} \
CONFIG.PCW_MIO_41_SLEW {slow} \
CONFIG.PCW_MIO_42_DIRECTION {inout} \
CONFIG.PCW_MIO_42_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_42_PULLUP {disabled} \
CONFIG.PCW_MIO_42_SLEW {slow} \
CONFIG.PCW_MIO_43_DIRECTION {inout} \
CONFIG.PCW_MIO_43_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_43_PULLUP {disabled} \
CONFIG.PCW_MIO_43_SLEW {slow} \
CONFIG.PCW_MIO_44_DIRECTION {inout} \
CONFIG.PCW_MIO_44_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_44_PULLUP {disabled} \
CONFIG.PCW_MIO_44_SLEW {slow} \
CONFIG.PCW_MIO_45_DIRECTION {inout} \
CONFIG.PCW_MIO_45_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_45_PULLUP {disabled} \
CONFIG.PCW_MIO_45_SLEW {slow} \
CONFIG.PCW_MIO_46_DIRECTION {inout} \
CONFIG.PCW_MIO_46_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_46_PULLUP {enabled} \
CONFIG.PCW_MIO_46_SLEW {slow} \
CONFIG.PCW_MIO_47_DIRECTION {inout} \
CONFIG.PCW_MIO_47_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_47_PULLUP {enabled} \
CONFIG.PCW_MIO_47_SLEW {slow} \
CONFIG.PCW_MIO_48_DIRECTION {inout} \
CONFIG.PCW_MIO_48_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_48_PULLUP {enabled} \
CONFIG.PCW_MIO_48_SLEW {slow} \
CONFIG.PCW_MIO_49_DIRECTION {inout} \
CONFIG.PCW_MIO_49_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_49_PULLUP {enabled} \
CONFIG.PCW_MIO_49_SLEW {slow} \
CONFIG.PCW_MIO_4_DIRECTION {inout} \
CONFIG.PCW_MIO_4_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_4_PULLUP {disabled} \
CONFIG.PCW_MIO_4_SLEW {slow} \
CONFIG.PCW_MIO_50_DIRECTION {out} \
CONFIG.PCW_MIO_50_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_50_PULLUP {enabled} \
CONFIG.PCW_MIO_50_SLEW {slow} \
CONFIG.PCW_MIO_51_DIRECTION {out} \
CONFIG.PCW_MIO_51_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_51_PULLUP {enabled} \
CONFIG.PCW_MIO_51_SLEW {slow} \
CONFIG.PCW_MIO_52_DIRECTION {out} \
CONFIG.PCW_MIO_52_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_52_PULLUP {enabled} \
CONFIG.PCW_MIO_52_SLEW {slow} \
CONFIG.PCW_MIO_53_DIRECTION {inout} \
CONFIG.PCW_MIO_53_IOTYPE {LVCMOS 1.8V} \
CONFIG.PCW_MIO_53_PULLUP {enabled} \
CONFIG.PCW_MIO_53_SLEW {slow} \
CONFIG.PCW_MIO_5_DIRECTION {inout} \
CONFIG.PCW_MIO_5_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_5_PULLUP {disabled} \
CONFIG.PCW_MIO_5_SLEW {slow} \
CONFIG.PCW_MIO_6_DIRECTION {out} \
CONFIG.PCW_MIO_6_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_6_PULLUP {disabled} \
CONFIG.PCW_MIO_6_SLEW {slow} \
CONFIG.PCW_MIO_7_DIRECTION {out} \
CONFIG.PCW_MIO_7_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_7_PULLUP {disabled} \
CONFIG.PCW_MIO_7_SLEW {slow} \
CONFIG.PCW_MIO_8_DIRECTION {out} \
CONFIG.PCW_MIO_8_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_8_PULLUP {disabled} \
CONFIG.PCW_MIO_8_SLEW {slow} \
CONFIG.PCW_MIO_9_DIRECTION {inout} \
CONFIG.PCW_MIO_9_IOTYPE {LVCMOS 3.3V} \
CONFIG.PCW_MIO_9_PULLUP {enabled} \
CONFIG.PCW_MIO_9_SLEW {slow} \
CONFIG.PCW_MIO_PRIMITIVE {54} \
CONFIG.PCW_M_AXI_GP0_ENABLE_STATIC_REMAP {0} \
CONFIG.PCW_M_AXI_GP0_FREQMHZ {50} \
CONFIG.PCW_M_AXI_GP0_ID_WIDTH {12} \
CONFIG.PCW_M_AXI_GP0_SUPPORT_NARROW_BURST {0} \
CONFIG.PCW_M_AXI_GP0_THREAD_ID_WIDTH {12} \
CONFIG.PCW_M_AXI_GP1_ENABLE_STATIC_REMAP {0} \
CONFIG.PCW_M_AXI_GP1_FREQMHZ {10} \
CONFIG.PCW_M_AXI_GP1_ID_WIDTH {12} \
CONFIG.PCW_M_AXI_GP1_SUPPORT_NARROW_BURST {0} \
CONFIG.PCW_M_AXI_GP1_THREAD_ID_WIDTH {12} \
CONFIG.PCW_NAND_CYCLES_T_AR {1} \
CONFIG.PCW_NAND_CYCLES_T_CLR {1} \
CONFIG.PCW_NAND_CYCLES_T_RC {2} \
CONFIG.PCW_NAND_CYCLES_T_REA {1} \
CONFIG.PCW_NAND_CYCLES_T_RR {1} \
CONFIG.PCW_NAND_CYCLES_T_WC {2} \
CONFIG.PCW_NAND_CYCLES_T_WP {1} \
CONFIG.PCW_NAND_GRP_D8_ENABLE {0} \
CONFIG.PCW_NAND_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_NOR_CS0_T_CEOE {1} \
CONFIG.PCW_NOR_CS0_T_PC {1} \
CONFIG.PCW_NOR_CS0_T_RC {2} \
CONFIG.PCW_NOR_CS0_T_TR {1} \
CONFIG.PCW_NOR_CS0_T_WC {2} \
CONFIG.PCW_NOR_CS0_T_WP {1} \
CONFIG.PCW_NOR_CS0_WE_TIME {0} \
CONFIG.PCW_NOR_CS1_T_CEOE {1} \
CONFIG.PCW_NOR_CS1_T_PC {1} \
CONFIG.PCW_NOR_CS1_T_RC {2} \
CONFIG.PCW_NOR_CS1_T_TR {1} \
CONFIG.PCW_NOR_CS1_T_WC {2} \
CONFIG.PCW_NOR_CS1_T_WP {1} \
CONFIG.PCW_NOR_CS1_WE_TIME {0} \
CONFIG.PCW_NOR_GRP_A25_ENABLE {0} \
CONFIG.PCW_NOR_GRP_CS0_ENABLE {0} \
CONFIG.PCW_NOR_GRP_CS1_ENABLE {0} \
CONFIG.PCW_NOR_GRP_SRAM_CS0_ENABLE {0} \
CONFIG.PCW_NOR_GRP_SRAM_CS1_ENABLE {0} \
CONFIG.PCW_NOR_GRP_SRAM_INT_ENABLE {0} \
CONFIG.PCW_NOR_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_NOR_SRAM_CS0_T_CEOE {1} \
CONFIG.PCW_NOR_SRAM_CS0_T_PC {1} \
CONFIG.PCW_NOR_SRAM_CS0_T_RC {2} \
CONFIG.PCW_NOR_SRAM_CS0_T_TR {1} \
CONFIG.PCW_NOR_SRAM_CS0_T_WC {2} \
CONFIG.PCW_NOR_SRAM_CS0_T_WP {1} \
CONFIG.PCW_NOR_SRAM_CS0_WE_TIME {0} \
CONFIG.PCW_NOR_SRAM_CS1_T_CEOE {1} \
CONFIG.PCW_NOR_SRAM_CS1_T_PC {1} \
CONFIG.PCW_NOR_SRAM_CS1_T_RC {2} \
CONFIG.PCW_NOR_SRAM_CS1_T_TR {1} \
CONFIG.PCW_NOR_SRAM_CS1_T_WC {2} \
CONFIG.PCW_NOR_SRAM_CS1_T_WP {1} \
CONFIG.PCW_NOR_SRAM_CS1_WE_TIME {0} \
CONFIG.PCW_OVERRIDE_BASIC_CLOCK {0} \
CONFIG.PCW_P2F_CAN0_INTR {0} \
CONFIG.PCW_P2F_CAN1_INTR {0} \
CONFIG.PCW_P2F_CTI_INTR {0} \
CONFIG.PCW_P2F_DMAC0_INTR {0} \
CONFIG.PCW_P2F_DMAC1_INTR {0} \
CONFIG.PCW_P2F_DMAC2_INTR {0} \
CONFIG.PCW_P2F_DMAC3_INTR {0} \
CONFIG.PCW_P2F_DMAC4_INTR {0} \
CONFIG.PCW_P2F_DMAC5_INTR {0} \
CONFIG.PCW_P2F_DMAC6_INTR {0} \
CONFIG.PCW_P2F_DMAC7_INTR {0} \
CONFIG.PCW_P2F_DMAC_ABORT_INTR {0} \
CONFIG.PCW_P2F_ENET0_INTR {0} \
CONFIG.PCW_P2F_ENET1_INTR {0} \
CONFIG.PCW_P2F_GPIO_INTR {0} \
CONFIG.PCW_P2F_I2C0_INTR {0} \
CONFIG.PCW_P2F_I2C1_INTR {0} \
CONFIG.PCW_P2F_QSPI_INTR {0} \
CONFIG.PCW_P2F_SDIO0_INTR {0} \
CONFIG.PCW_P2F_SDIO1_INTR {0} \
CONFIG.PCW_P2F_SMC_INTR {0} \
CONFIG.PCW_P2F_SPI0_INTR {0} \
CONFIG.PCW_P2F_SPI1_INTR {0} \
CONFIG.PCW_P2F_UART0_INTR {0} \
CONFIG.PCW_P2F_UART1_INTR {0} \
CONFIG.PCW_P2F_USB0_INTR {0} \
CONFIG.PCW_P2F_USB1_INTR {0} \
CONFIG.PCW_PACKAGE_DDR_BOARD_DELAY0 {0.075} \
CONFIG.PCW_PACKAGE_DDR_BOARD_DELAY1 {0.070} \
CONFIG.PCW_PACKAGE_DDR_BOARD_DELAY2 {0.077} \
CONFIG.PCW_PACKAGE_DDR_BOARD_DELAY3 {0.094} \
CONFIG.PCW_PACKAGE_DDR_DQS_TO_CLK_DELAY_0 {-0.000} \
CONFIG.PCW_PACKAGE_DDR_DQS_TO_CLK_DELAY_1 {-0.001} \
CONFIG.PCW_PACKAGE_DDR_DQS_TO_CLK_DELAY_2 {0.004} \
CONFIG.PCW_PACKAGE_DDR_DQS_TO_CLK_DELAY_3 {-0.035} \
CONFIG.PCW_PACKAGE_NAME {sbg485} \
CONFIG.PCW_PCAP_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_PCAP_PERIPHERAL_DIVISOR0 {5} \
CONFIG.PCW_PCAP_PERIPHERAL_FREQMHZ {200} \
CONFIG.PCW_PERIPHERAL_BOARD_PRESET {part0} \
CONFIG.PCW_PJTAG_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_PRESET_BANK0_VOLTAGE {LVCMOS 3.3V} \
CONFIG.PCW_PRESET_BANK1_VOLTAGE {LVCMOS 1.8V} \
CONFIG.PCW_PS7_SI_REV {PRODUCTION} \
CONFIG.PCW_QSPI_GRP_FBCLK_ENABLE {1} \
CONFIG.PCW_QSPI_GRP_FBCLK_IO {MIO 8} \
CONFIG.PCW_QSPI_GRP_IO1_ENABLE {0} \
CONFIG.PCW_QSPI_GRP_SINGLE_SS_ENABLE {1} \
CONFIG.PCW_QSPI_GRP_SINGLE_SS_IO {MIO 1 .. 6} \
CONFIG.PCW_QSPI_GRP_SS1_ENABLE {0} \
CONFIG.PCW_QSPI_INTERNAL_HIGHADDRESS {0xFCFFFFFF} \
CONFIG.PCW_QSPI_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_QSPI_PERIPHERAL_DIVISOR0 {5} \
CONFIG.PCW_QSPI_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_QSPI_PERIPHERAL_FREQMHZ {200} \
CONFIG.PCW_QSPI_QSPI_IO {MIO 1 .. 6} \
CONFIG.PCW_SD0_GRP_CD_ENABLE {0} \
CONFIG.PCW_SD0_GRP_POW_ENABLE {0} \
CONFIG.PCW_SD0_GRP_WP_ENABLE {0} \
CONFIG.PCW_SD0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_SD0_SD0_IO {MIO 40 .. 45} \
CONFIG.PCW_SD1_GRP_CD_ENABLE {0} \
CONFIG.PCW_SD1_GRP_POW_ENABLE {0} \
CONFIG.PCW_SD1_GRP_WP_ENABLE {0} \
CONFIG.PCW_SD1_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_SDIO0_BASEADDR {0xE0100000} \
CONFIG.PCW_SDIO0_HIGHADDR {0xE0100FFF} \
CONFIG.PCW_SDIO1_BASEADDR {0xE0101000} \
CONFIG.PCW_SDIO1_HIGHADDR {0xE0101FFF} \
CONFIG.PCW_SDIO_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_SDIO_PERIPHERAL_DIVISOR0 {10} \
CONFIG.PCW_SDIO_PERIPHERAL_FREQMHZ {100} \
CONFIG.PCW_SDIO_PERIPHERAL_VALID {1} \
CONFIG.PCW_SMC_CYCLE_T0 {NA} \
CONFIG.PCW_SMC_CYCLE_T1 {NA} \
CONFIG.PCW_SMC_CYCLE_T2 {NA} \
CONFIG.PCW_SMC_CYCLE_T3 {NA} \
CONFIG.PCW_SMC_CYCLE_T4 {NA} \
CONFIG.PCW_SMC_CYCLE_T5 {NA} \
CONFIG.PCW_SMC_CYCLE_T6 {NA} \
CONFIG.PCW_SMC_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_SMC_PERIPHERAL_DIVISOR0 {1} \
CONFIG.PCW_SMC_PERIPHERAL_FREQMHZ {100} \
CONFIG.PCW_SMC_PERIPHERAL_VALID {0} \
CONFIG.PCW_SPI0_BASEADDR {0xE0006000} \
CONFIG.PCW_SPI0_GRP_SS0_ENABLE {0} \
CONFIG.PCW_SPI0_GRP_SS1_ENABLE {0} \
CONFIG.PCW_SPI0_GRP_SS2_ENABLE {0} \
CONFIG.PCW_SPI0_HIGHADDR {0xE0006FFF} \
CONFIG.PCW_SPI0_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_SPI1_BASEADDR {0xE0007000} \
CONFIG.PCW_SPI1_GRP_SS0_ENABLE {0} \
CONFIG.PCW_SPI1_GRP_SS1_ENABLE {0} \
CONFIG.PCW_SPI1_GRP_SS2_ENABLE {0} \
CONFIG.PCW_SPI1_HIGHADDR {0xE0007FFF} \
CONFIG.PCW_SPI1_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_SPI_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_SPI_PERIPHERAL_DIVISOR0 {1} \
CONFIG.PCW_SPI_PERIPHERAL_FREQMHZ {166.666666} \
CONFIG.PCW_SPI_PERIPHERAL_VALID {0} \
CONFIG.PCW_S_AXI_ACP_ARUSER_VAL {31} \
CONFIG.PCW_S_AXI_ACP_AWUSER_VAL {31} \
CONFIG.PCW_S_AXI_ACP_FREQMHZ {10} \
CONFIG.PCW_S_AXI_ACP_ID_WIDTH {3} \
CONFIG.PCW_S_AXI_GP0_FREQMHZ {10} \
CONFIG.PCW_S_AXI_GP0_ID_WIDTH {6} \
CONFIG.PCW_S_AXI_GP1_FREQMHZ {10} \
CONFIG.PCW_S_AXI_GP1_ID_WIDTH {6} \
CONFIG.PCW_S_AXI_HP0_DATA_WIDTH {64} \
CONFIG.PCW_S_AXI_HP0_FREQMHZ {10} \
CONFIG.PCW_S_AXI_HP0_ID_WIDTH {6} \
CONFIG.PCW_S_AXI_HP1_DATA_WIDTH {64} \
CONFIG.PCW_S_AXI_HP1_FREQMHZ {10} \
CONFIG.PCW_S_AXI_HP1_ID_WIDTH {6} \
CONFIG.PCW_S_AXI_HP2_DATA_WIDTH {64} \
CONFIG.PCW_S_AXI_HP2_FREQMHZ {10} \
CONFIG.PCW_S_AXI_HP2_ID_WIDTH {6} \
CONFIG.PCW_S_AXI_HP3_DATA_WIDTH {64} \
CONFIG.PCW_S_AXI_HP3_FREQMHZ {10} \
CONFIG.PCW_S_AXI_HP3_ID_WIDTH {6} \
CONFIG.PCW_TPIU_PERIPHERAL_CLKSRC {External} \
CONFIG.PCW_TPIU_PERIPHERAL_DIVISOR0 {1} \
CONFIG.PCW_TPIU_PERIPHERAL_FREQMHZ {200} \
CONFIG.PCW_TRACE_BUFFER_CLOCK_DELAY {12} \
CONFIG.PCW_TRACE_BUFFER_FIFO_SIZE {128} \
CONFIG.PCW_TRACE_GRP_16BIT_ENABLE {0} \
CONFIG.PCW_TRACE_GRP_2BIT_ENABLE {0} \
CONFIG.PCW_TRACE_GRP_32BIT_ENABLE {0} \
CONFIG.PCW_TRACE_GRP_4BIT_ENABLE {0} \
CONFIG.PCW_TRACE_GRP_8BIT_ENABLE {0} \
CONFIG.PCW_TRACE_INTERNAL_WIDTH {2} \
CONFIG.PCW_TRACE_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_TRACE_PIPELINE_WIDTH {8} \
CONFIG.PCW_TTC0_BASEADDR {0xE0104000} \
CONFIG.PCW_TTC0_CLK0_PERIPHERAL_CLKSRC {CPU_1X} \
CONFIG.PCW_TTC0_CLK0_PERIPHERAL_DIVISOR0 {1} \
CONFIG.PCW_TTC0_CLK0_PERIPHERAL_FREQMHZ {133.333333} \
CONFIG.PCW_TTC0_CLK1_PERIPHERAL_CLKSRC {CPU_1X} \
CONFIG.PCW_TTC0_CLK1_PERIPHERAL_DIVISOR0 {1} \
CONFIG.PCW_TTC0_CLK1_PERIPHERAL_FREQMHZ {133.333333} \
CONFIG.PCW_TTC0_CLK2_PERIPHERAL_CLKSRC {CPU_1X} \
CONFIG.PCW_TTC0_CLK2_PERIPHERAL_DIVISOR0 {1} \
CONFIG.PCW_TTC0_CLK2_PERIPHERAL_FREQMHZ {133.333333} \
CONFIG.PCW_TTC0_HIGHADDR {0xE0104fff} \
CONFIG.PCW_TTC0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_TTC0_TTC0_IO {EMIO} \
CONFIG.PCW_TTC1_BASEADDR {0xE0105000} \
CONFIG.PCW_TTC1_CLK0_PERIPHERAL_CLKSRC {CPU_1X} \
CONFIG.PCW_TTC1_CLK0_PERIPHERAL_DIVISOR0 {1} \
CONFIG.PCW_TTC1_CLK0_PERIPHERAL_FREQMHZ {133.333333} \
CONFIG.PCW_TTC1_CLK1_PERIPHERAL_CLKSRC {CPU_1X} \
CONFIG.PCW_TTC1_CLK1_PERIPHERAL_DIVISOR0 {1} \
CONFIG.PCW_TTC1_CLK1_PERIPHERAL_FREQMHZ {133.333333} \
CONFIG.PCW_TTC1_CLK2_PERIPHERAL_CLKSRC {CPU_1X} \
CONFIG.PCW_TTC1_CLK2_PERIPHERAL_DIVISOR0 {1} \
CONFIG.PCW_TTC1_CLK2_PERIPHERAL_FREQMHZ {133.333333} \
CONFIG.PCW_TTC1_HIGHADDR {0xE0105fff} \
CONFIG.PCW_TTC1_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_TTC1_TTC1_IO {EMIO} \
CONFIG.PCW_TTC_PERIPHERAL_FREQMHZ {50} \
CONFIG.PCW_UART0_BASEADDR {0xE0000000} \
CONFIG.PCW_UART0_BAUD_RATE {115200} \
CONFIG.PCW_UART0_GRP_FULL_ENABLE {0} \
CONFIG.PCW_UART0_HIGHADDR {0xE0000FFF} \
CONFIG.PCW_UART0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_UART0_UART0_IO {MIO 14 .. 15} \
CONFIG.PCW_UART1_BASEADDR {0xE0001000} \
CONFIG.PCW_UART1_BAUD_RATE {115200} \
CONFIG.PCW_UART1_GRP_FULL_ENABLE {0} \
CONFIG.PCW_UART1_HIGHADDR {0xE0001FFF} \
CONFIG.PCW_UART1_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_UART1_UART1_IO {MIO 12 .. 13} \
CONFIG.PCW_UART_PERIPHERAL_CLKSRC {IO PLL} \
CONFIG.PCW_UART_PERIPHERAL_DIVISOR0 {10} \
CONFIG.PCW_UART_PERIPHERAL_FREQMHZ {100} \
CONFIG.PCW_UART_PERIPHERAL_VALID {1} \
CONFIG.PCW_UIPARAM_ACT_DDR_FREQ_MHZ {533.333374} \
CONFIG.PCW_UIPARAM_DDR_ADV_ENABLE {0} \
CONFIG.PCW_UIPARAM_DDR_AL {0} \
CONFIG.PCW_UIPARAM_DDR_BANK_ADDR_COUNT {3} \
CONFIG.PCW_UIPARAM_DDR_BL {8} \
CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY0 {0.012} \
CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY1 {0.011} \
CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY2 {0.012} \
CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY3 {0.015} \
CONFIG.PCW_UIPARAM_DDR_BUS_WIDTH {32 Bit} \
CONFIG.PCW_UIPARAM_DDR_CL {7} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_0_LENGTH_MM {0} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_0_PACKAGE_LENGTH {76.428} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_0_PROPOGATION_DELAY {160} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_1_LENGTH_MM {0} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_1_PACKAGE_LENGTH {76.428} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_1_PROPOGATION_DELAY {160} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_2_LENGTH_MM {0} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_2_PACKAGE_LENGTH {76.428} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_2_PROPOGATION_DELAY {160} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_3_LENGTH_MM {0} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_3_PACKAGE_LENGTH {76.428} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_3_PROPOGATION_DELAY {160} \
CONFIG.PCW_UIPARAM_DDR_CLOCK_STOP_EN {0} \
CONFIG.PCW_UIPARAM_DDR_COL_ADDR_COUNT {10} \
CONFIG.PCW_UIPARAM_DDR_CWL {6} \
CONFIG.PCW_UIPARAM_DDR_DEVICE_CAPACITY {4096 MBits} \
CONFIG.PCW_UIPARAM_DDR_DQS_0_LENGTH_MM {0} \
CONFIG.PCW_UIPARAM_DDR_DQS_0_PACKAGE_LENGTH {76.687} \
CONFIG.PCW_UIPARAM_DDR_DQS_0_PROPOGATION_DELAY {160} \
CONFIG.PCW_UIPARAM_DDR_DQS_1_LENGTH_MM {0} \
CONFIG.PCW_UIPARAM_DDR_DQS_1_PACKAGE_LENGTH {77.8025} \
CONFIG.PCW_UIPARAM_DDR_DQS_1_PROPOGATION_DELAY {160} \
CONFIG.PCW_UIPARAM_DDR_DQS_2_LENGTH_MM {0} \
CONFIG.PCW_UIPARAM_DDR_DQS_2_PACKAGE_LENGTH {72.8405} \
CONFIG.PCW_UIPARAM_DDR_DQS_2_PROPOGATION_DELAY {160} \
CONFIG.PCW_UIPARAM_DDR_DQS_3_LENGTH_MM {0} \
CONFIG.PCW_UIPARAM_DDR_DQS_3_PACKAGE_LENGTH {111.904} \
CONFIG.PCW_UIPARAM_DDR_DQS_3_PROPOGATION_DELAY {160} \
CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_0 {0.0} \
CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_1 {0.0} \
CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_2 {0.001} \
CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_3 {-0.006} \
CONFIG.PCW_UIPARAM_DDR_DQ_0_LENGTH_MM {0} \
CONFIG.PCW_UIPARAM_DDR_DQ_0_PACKAGE_LENGTH {73.119} \
CONFIG.PCW_UIPARAM_DDR_DQ_0_PROPOGATION_DELAY {160} \
CONFIG.PCW_UIPARAM_DDR_DQ_1_LENGTH_MM {0} \
CONFIG.PCW_UIPARAM_DDR_DQ_1_PACKAGE_LENGTH {63.8935} \
CONFIG.PCW_UIPARAM_DDR_DQ_1_PROPOGATION_DELAY {160} \
CONFIG.PCW_UIPARAM_DDR_DQ_2_LENGTH_MM {0} \
CONFIG.PCW_UIPARAM_DDR_DQ_2_PACKAGE_LENGTH {77.045} \
CONFIG.PCW_UIPARAM_DDR_DQ_2_PROPOGATION_DELAY {160} \
CONFIG.PCW_UIPARAM_DDR_DQ_3_LENGTH_MM {0} \
CONFIG.PCW_UIPARAM_DDR_DQ_3_PACKAGE_LENGTH {111.903} \
CONFIG.PCW_UIPARAM_DDR_DQ_3_PROPOGATION_DELAY {160} \
CONFIG.PCW_UIPARAM_DDR_DRAM_WIDTH {16 Bits} \
CONFIG.PCW_UIPARAM_DDR_ECC {Disabled} \
CONFIG.PCW_UIPARAM_DDR_ENABLE {1} \
CONFIG.PCW_UIPARAM_DDR_FREQ_MHZ {533.333333} \
CONFIG.PCW_UIPARAM_DDR_HIGH_TEMP {Normal (0-85)} \
CONFIG.PCW_UIPARAM_DDR_MEMORY_TYPE {DDR 3} \
CONFIG.PCW_UIPARAM_DDR_PARTNO {MT41J256M16 RE-125} \
CONFIG.PCW_UIPARAM_DDR_ROW_ADDR_COUNT {15} \
CONFIG.PCW_UIPARAM_DDR_SPEED_BIN {DDR3_1066F} \
CONFIG.PCW_UIPARAM_DDR_TRAIN_DATA_EYE {1} \
CONFIG.PCW_UIPARAM_DDR_TRAIN_READ_GATE {0} \
CONFIG.PCW_UIPARAM_DDR_TRAIN_WRITE_LEVEL {1} \
CONFIG.PCW_UIPARAM_DDR_T_FAW {40.0} \
CONFIG.PCW_UIPARAM_DDR_T_RAS_MIN {35.0} \
CONFIG.PCW_UIPARAM_DDR_T_RC {48.91} \
CONFIG.PCW_UIPARAM_DDR_T_RCD {7} \
CONFIG.PCW_UIPARAM_DDR_T_RP {7} \
CONFIG.PCW_UIPARAM_DDR_USE_INTERNAL_VREF {0} \
CONFIG.PCW_UIPARAM_GENERATE_SUMMARY {NONE} \
CONFIG.PCW_USB0_BASEADDR {0xE0102000} \
CONFIG.PCW_USB0_HIGHADDR {0xE0102fff} \
CONFIG.PCW_USB0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_USB0_PERIPHERAL_FREQMHZ {60} \
CONFIG.PCW_USB0_RESET_ENABLE {1} \
CONFIG.PCW_USB0_RESET_IO {MIO 51} \
CONFIG.PCW_USB0_USB0_IO {MIO 28 .. 39} \
CONFIG.PCW_USB1_BASEADDR {0xE0103000} \
CONFIG.PCW_USB1_HIGHADDR {0xE0103fff} \
CONFIG.PCW_USB1_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_USB1_PERIPHERAL_FREQMHZ {60} \
CONFIG.PCW_USB1_RESET_ENABLE {0} \
CONFIG.PCW_USB_RESET_ENABLE {1} \
CONFIG.PCW_USB_RESET_POLARITY {Active Low} \
CONFIG.PCW_USB_RESET_SELECT {Share reset pin} \
CONFIG.PCW_USE_AXI_FABRIC_IDLE {0} \
CONFIG.PCW_USE_AXI_NONSECURE {0} \
CONFIG.PCW_USE_CORESIGHT {0} \
CONFIG.PCW_USE_CROSS_TRIGGER {0} \
CONFIG.PCW_USE_CR_FABRIC {1} \
CONFIG.PCW_USE_DDR_BYPASS {0} \
CONFIG.PCW_USE_DEBUG {0} \
CONFIG.PCW_USE_DEFAULT_ACP_USER_VAL {0} \
CONFIG.PCW_USE_DMA0 {0} \
CONFIG.PCW_USE_DMA1 {0} \
CONFIG.PCW_USE_DMA2 {0} \
CONFIG.PCW_USE_DMA3 {0} \
CONFIG.PCW_USE_EXPANDED_IOP {0} \
CONFIG.PCW_USE_EXPANDED_PS_SLCR_REGISTERS {0} \
CONFIG.PCW_USE_FABRIC_INTERRUPT {1} \
CONFIG.PCW_USE_HIGH_OCM {0} \
CONFIG.PCW_USE_M_AXI_GP0 {1} \
CONFIG.PCW_USE_M_AXI_GP1 {1} \
CONFIG.PCW_USE_PROC_EVENT_BUS {0} \
CONFIG.PCW_USE_PS_SLCR_REGISTERS {0} \
CONFIG.PCW_USE_S_AXI_ACP {0} \
CONFIG.PCW_USE_S_AXI_GP0 {0} \
CONFIG.PCW_USE_S_AXI_GP1 {0} \
CONFIG.PCW_USE_S_AXI_HP0 {1} \
CONFIG.PCW_USE_S_AXI_HP1 {1} \
CONFIG.PCW_USE_S_AXI_HP2 {1} \
CONFIG.PCW_USE_S_AXI_HP3 {0} \
CONFIG.PCW_USE_TRACE {0} \
CONFIG.PCW_USE_TRACE_DATA_EDGE_DETECTOR {0} \
CONFIG.PCW_VALUE_SILVERSION {3} \
CONFIG.PCW_WDT_PERIPHERAL_CLKSRC {CPU_1X} \
CONFIG.PCW_WDT_PERIPHERAL_DIVISOR0 {1} \
CONFIG.PCW_WDT_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_WDT_PERIPHERAL_FREQMHZ {133.333333} \
 ] $processing_system7_0

  # Create instance: processing_system7_0_axi_periph, and set properties
  set processing_system7_0_axi_periph [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 processing_system7_0_axi_periph ]
  set_property -dict [ list \
CONFIG.NUM_MI {4} \
 ] $processing_system7_0_axi_periph

  # Create instance: sobel_filter_0, and set properties
  set sobel_filter_0 [ create_bd_cell -type ip -vlnv xilinx.com:hls:sobel_filter:1.0 sobel_filter_0 ]

  # Create instance: sobel_filter_0_if, and set properties
  set sobel_filter_0_if [ create_bd_cell -type ip -vlnv xilinx.com:ip:axis_accelerator_adapter:2.1 sobel_filter_0_if ]
  set_property -dict [ list \
CONFIG.C_AP_IARG_0_DIM_1 {1024} \
CONFIG.C_AP_IARG_0_DWIDTH {16} \
CONFIG.C_AP_IARG_0_TYPE {1} \
CONFIG.C_AP_IARG_0_WIDTH {16} \
CONFIG.C_AP_OARG_0_DIM_1 {1024} \
CONFIG.C_AP_OARG_0_DWIDTH {8} \
CONFIG.C_AP_OARG_0_TYPE {1} \
CONFIG.C_AP_OARG_0_WIDTH {8} \
CONFIG.C_M_AXIS_HAS_TKEEP {1} \
CONFIG.C_M_AXIS_HAS_TSTRB {1} \
CONFIG.C_M_AXIS_TDATA_WIDTH {64} \
CONFIG.C_N_INPUT_ARGS {1} \
CONFIG.C_N_OUTPUT_ARGS {1} \
CONFIG.C_S_AXIS_TDATA_WIDTH {64} \
 ] $sobel_filter_0_if

  # Create instance: sobel_filter_pass_0, and set properties
  set sobel_filter_pass_0 [ create_bd_cell -type ip -vlnv xilinx.com:hls:sobel_filter_pass:1.0 sobel_filter_pass_0 ]

  # Create instance: sobel_filter_pass_0_if, and set properties
  set sobel_filter_pass_0_if [ create_bd_cell -type ip -vlnv xilinx.com:ip:axis_accelerator_adapter:2.1 sobel_filter_pass_0_if ]
  set_property -dict [ list \
CONFIG.C_AP_IARG_0_DIM_1 {1024} \
CONFIG.C_AP_IARG_0_DWIDTH {16} \
CONFIG.C_AP_IARG_0_TYPE {1} \
CONFIG.C_AP_IARG_0_WIDTH {16} \
CONFIG.C_AP_OARG_0_DIM_1 {1024} \
CONFIG.C_AP_OARG_0_DWIDTH {8} \
CONFIG.C_AP_OARG_0_TYPE {1} \
CONFIG.C_AP_OARG_0_WIDTH {8} \
CONFIG.C_AP_OARG_1_DIM_1 {1024} \
CONFIG.C_AP_OARG_1_DWIDTH {16} \
CONFIG.C_AP_OARG_1_TYPE {1} \
CONFIG.C_AP_OARG_1_WIDTH {16} \
CONFIG.C_M_AXIS_HAS_TKEEP {1} \
CONFIG.C_M_AXIS_HAS_TSTRB {1} \
CONFIG.C_M_AXIS_TDATA_WIDTH {64} \
CONFIG.C_N_INPUT_ARGS {1} \
CONFIG.C_N_OUTPUT_ARGS {2} \
CONFIG.C_S_AXIS_TDATA_WIDTH {64} \
 ] $sobel_filter_pass_0_if

  # Create instance: xlconcat_0, and set properties
  set xlconcat_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat:2.1 xlconcat_0 ]
  set_property -dict [ list \
CONFIG.NUM_PORTS {3} \
 ] $xlconcat_0

  # Create interface connections
  connect_bd_intf_net -intf_net HDMI_vid_in_1 [get_bd_intf_ports hdmii] [get_bd_intf_pins imageon_hdmi_in/IO_HDMII]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M00_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M00_AXI] [get_bd_intf_pins combo_image_0_if/S_AXI]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M01_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M01_AXI] [get_bd_intf_pins diff_image_0_if/S_AXI]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M02_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M02_AXI] [get_bd_intf_pins ext_0_if/S_AXI]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M03_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M03_AXI] [get_bd_intf_pins median_char_filter_pass_0_if/S_AXI]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M04_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M04_AXI] [get_bd_intf_pins pad_0_if/S_AXI]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M05_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M05_AXI] [get_bd_intf_pins pad_1_if/S_AXI]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M06_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M06_AXI] [get_bd_intf_pins sobel_filter_0_if/S_AXI]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M07_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M07_AXI] [get_bd_intf_pins sobel_filter_pass_0_if/S_AXI]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M08_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M08_AXI] [get_bd_intf_pins dm_0/S_AXI_LITE]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M09_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M09_AXI] [get_bd_intf_pins dm_1/S_AXI_LITE]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_M_AXI_GP1_M10_AXI [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/M10_AXI] [get_bd_intf_pins dm_2/S_AXI_LITE]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_S_AXI_HP1_M00_AXI [get_bd_intf_pins axi_ic_processing_system7_0_S_AXI_HP1/M00_AXI] [get_bd_intf_pins processing_system7_0/S_AXI_HP1]
  connect_bd_intf_net -intf_net axi_ic_processing_system7_0_S_AXI_HP2_M00_AXI [get_bd_intf_pins axi_ic_processing_system7_0_S_AXI_HP2/M00_AXI] [get_bd_intf_pins processing_system7_0/S_AXI_HP2]
  connect_bd_intf_net -intf_net axi_vdma_0_M_AXI_MM2S [get_bd_intf_pins axi_interconnect_0/S00_AXI] [get_bd_intf_pins axi_vdma_0/M_AXI_MM2S]
  connect_bd_intf_net -intf_net axi_vdma_0_M_AXI_S2MM [get_bd_intf_pins axi_interconnect_0/S01_AXI] [get_bd_intf_pins axi_vdma_0/M_AXI_S2MM]
  connect_bd_intf_net -intf_net combo_image_0_if_AP_CTRL [get_bd_intf_pins combo_image_0/ap_ctrl] [get_bd_intf_pins combo_image_0_if/AP_CTRL]
  connect_bd_intf_net -intf_net combo_image_0_if_M_AXIS_0 [get_bd_intf_pins combo_image_0_if/M_AXIS_0] [get_bd_intf_pins ext_0_if/S_AXIS_0]
  connect_bd_intf_net -intf_net combo_image_0_motion_image [get_bd_intf_pins combo_image_0/motion_image] [get_bd_intf_pins combo_image_0_if/AP_FIFO_IARG_0]
  connect_bd_intf_net -intf_net combo_image_0_original [get_bd_intf_pins combo_image_0/original] [get_bd_intf_pins combo_image_0_if/AP_FIFO_IARG_1]
  connect_bd_intf_net -intf_net combo_image_0_output_image [get_bd_intf_pins combo_image_0/output_image] [get_bd_intf_pins combo_image_0_if/AP_FIFO_OARG_0]
  connect_bd_intf_net -intf_net diff_image_0_current_pix [get_bd_intf_pins diff_image_0/current_pix] [get_bd_intf_pins diff_image_0_if/AP_FIFO_IARG_0]
  connect_bd_intf_net -intf_net diff_image_0_if_AP_CTRL [get_bd_intf_pins diff_image_0/ap_ctrl] [get_bd_intf_pins diff_image_0_if/AP_CTRL]
  connect_bd_intf_net -intf_net diff_image_0_if_M_AXIS_0 [get_bd_intf_pins diff_image_0_if/M_AXIS_0] [get_bd_intf_pins median_char_filter_pass_0_if/S_AXIS_1]
  connect_bd_intf_net -intf_net diff_image_0_if_M_AXIS_1 [get_bd_intf_pins diff_image_0_if/M_AXIS_1] [get_bd_intf_pins median_char_filter_pass_0_if/S_AXIS_0]
  connect_bd_intf_net -intf_net diff_image_0_motion_image [get_bd_intf_pins diff_image_0/motion_image] [get_bd_intf_pins diff_image_0_if/AP_FIFO_OARG_1]
  connect_bd_intf_net -intf_net diff_image_0_original [get_bd_intf_pins diff_image_0/original] [get_bd_intf_pins diff_image_0_if/AP_FIFO_IARG_2]
  connect_bd_intf_net -intf_net diff_image_0_original_output [get_bd_intf_pins diff_image_0/original_output] [get_bd_intf_pins diff_image_0_if/AP_FIFO_OARG_0]
  connect_bd_intf_net -intf_net diff_image_0_previous_pix [get_bd_intf_pins diff_image_0/previous_pix] [get_bd_intf_pins diff_image_0_if/AP_FIFO_IARG_1]
  connect_bd_intf_net -intf_net dm_0_M_AXIS_MM2S [get_bd_intf_pins dm_0/M_AXIS_MM2S] [get_bd_intf_pins pad_1_if/S_AXIS_0]
  connect_bd_intf_net -intf_net dm_0_M_AXI_MM2S [get_bd_intf_pins axi_ic_processing_system7_0_S_AXI_HP1/S00_AXI] [get_bd_intf_pins dm_0/M_AXI_MM2S]
  connect_bd_intf_net -intf_net dm_1_M_AXIS_MM2S [get_bd_intf_pins dm_1/M_AXIS_MM2S] [get_bd_intf_pins pad_0_if/S_AXIS_0]
  connect_bd_intf_net -intf_net dm_1_M_AXI_MM2S [get_bd_intf_pins axi_ic_processing_system7_0_S_AXI_HP2/S00_AXI] [get_bd_intf_pins dm_1/M_AXI_MM2S]
  connect_bd_intf_net -intf_net dm_2_M_AXI_S2MM [get_bd_intf_pins axi_ic_processing_system7_0_S_AXI_HP1/S01_AXI] [get_bd_intf_pins dm_2/M_AXI_S2MM]
  connect_bd_intf_net -intf_net ext_0_if_AP_CTRL [get_bd_intf_pins ext_0/ap_ctrl] [get_bd_intf_pins ext_0_if/AP_CTRL]
  connect_bd_intf_net -intf_net ext_0_if_M_AXIS_0 [get_bd_intf_pins dm_2/S_AXIS_S2MM] [get_bd_intf_pins ext_0_if/M_AXIS_0]
  connect_bd_intf_net -intf_net ext_0_in_r [get_bd_intf_pins ext_0/in_r] [get_bd_intf_pins ext_0_if/AP_FIFO_IARG_0]
  connect_bd_intf_net -intf_net ext_0_out_r [get_bd_intf_pins ext_0/out_r] [get_bd_intf_pins ext_0_if/AP_FIFO_OARG_0]
  connect_bd_intf_net -intf_net fmc2_imageon_iic_IIC [get_bd_intf_ports imageon_iic] [get_bd_intf_pins fmc2_imageon_iic/IIC]
  connect_bd_intf_net -intf_net fmc_imageon_hdmi_out_0_IO_HDMIO [get_bd_intf_ports hdmio] [get_bd_intf_pins imageon_hdmi_out/HDMI_vid_out]
  connect_bd_intf_net -intf_net median_char_filter_pass_0_if_AP_CTRL [get_bd_intf_pins median_char_filter_pass_0/ap_ctrl] [get_bd_intf_pins median_char_filter_pass_0_if/AP_CTRL]
  connect_bd_intf_net -intf_net median_char_filter_pass_0_if_M_AXIS_0 [get_bd_intf_pins combo_image_0_if/S_AXIS_0] [get_bd_intf_pins median_char_filter_pass_0_if/M_AXIS_0]
  connect_bd_intf_net -intf_net median_char_filter_pass_0_if_M_AXIS_1 [get_bd_intf_pins combo_image_0_if/S_AXIS_1] [get_bd_intf_pins median_char_filter_pass_0_if/M_AXIS_1]
  connect_bd_intf_net -intf_net median_char_filter_pass_0_input_edge [get_bd_intf_pins median_char_filter_pass_0/input_edge] [get_bd_intf_pins median_char_filter_pass_0_if/AP_FIFO_IARG_0]
  connect_bd_intf_net -intf_net median_char_filter_pass_0_input_pix [get_bd_intf_pins median_char_filter_pass_0/input_pix] [get_bd_intf_pins median_char_filter_pass_0_if/AP_FIFO_IARG_1]
  connect_bd_intf_net -intf_net median_char_filter_pass_0_median_pix [get_bd_intf_pins median_char_filter_pass_0/median_pix] [get_bd_intf_pins median_char_filter_pass_0_if/AP_FIFO_OARG_0]
  connect_bd_intf_net -intf_net median_char_filter_pass_0_original_pix [get_bd_intf_pins median_char_filter_pass_0/original_pix] [get_bd_intf_pins median_char_filter_pass_0_if/AP_FIFO_OARG_1]
  connect_bd_intf_net -intf_net pad_0_if_AP_CTRL [get_bd_intf_pins pad_0/ap_ctrl] [get_bd_intf_pins pad_0_if/AP_CTRL]
  connect_bd_intf_net -intf_net pad_0_if_M_AXIS_0 [get_bd_intf_pins pad_0_if/M_AXIS_0] [get_bd_intf_pins sobel_filter_pass_0_if/S_AXIS_0]
  connect_bd_intf_net -intf_net pad_0_yuv_data_in [get_bd_intf_pins pad_0/yuv_data_in] [get_bd_intf_pins pad_0_if/AP_FIFO_IARG_0]
  connect_bd_intf_net -intf_net pad_0_yuv_data_out [get_bd_intf_pins pad_0/yuv_data_out] [get_bd_intf_pins pad_0_if/AP_FIFO_OARG_0]
  connect_bd_intf_net -intf_net pad_1_if_AP_CTRL [get_bd_intf_pins pad_1/ap_ctrl] [get_bd_intf_pins pad_1_if/AP_CTRL]
  connect_bd_intf_net -intf_net pad_1_if_M_AXIS_0 [get_bd_intf_pins pad_1_if/M_AXIS_0] [get_bd_intf_pins sobel_filter_0_if/S_AXIS_0]
  connect_bd_intf_net -intf_net pad_1_yuv_data_in [get_bd_intf_pins pad_1/yuv_data_in] [get_bd_intf_pins pad_1_if/AP_FIFO_IARG_0]
  connect_bd_intf_net -intf_net pad_1_yuv_data_out [get_bd_intf_pins pad_1/yuv_data_out] [get_bd_intf_pins pad_1_if/AP_FIFO_OARG_0]
  connect_bd_intf_net -intf_net processing_system7_0_DDR [get_bd_intf_ports DDR] [get_bd_intf_pins processing_system7_0/DDR]
  connect_bd_intf_net -intf_net processing_system7_0_FIXED_IO [get_bd_intf_ports FIXED_IO] [get_bd_intf_pins processing_system7_0/FIXED_IO]
  connect_bd_intf_net -intf_net processing_system7_0_M_AXI_GP0 [get_bd_intf_pins processing_system7_0/M_AXI_GP0] [get_bd_intf_pins processing_system7_0_axi_periph/S00_AXI]
  connect_bd_intf_net -intf_net processing_system7_0_M_AXI_GP1 [get_bd_intf_pins axi_ic_processing_system7_0_M_AXI_GP1/S00_AXI] [get_bd_intf_pins processing_system7_0/M_AXI_GP1]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M00_AXI [get_bd_intf_pins fmc2_imageon_iic/S_AXI] [get_bd_intf_pins processing_system7_0_axi_periph/M00_AXI]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M01_AXI [get_bd_intf_pins imageon_hdmi_out/AXI_lite] [get_bd_intf_pins processing_system7_0_axi_periph/M01_AXI]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M02_AXI [get_bd_intf_pins axi_vdma_0/S_AXI_LITE] [get_bd_intf_pins processing_system7_0_axi_periph/M02_AXI]
  connect_bd_intf_net -intf_net processing_system7_0_axi_periph_M03_AXI [get_bd_intf_pins clkgen_variable/s_axi_lite] [get_bd_intf_pins processing_system7_0_axi_periph/M03_AXI]
  connect_bd_intf_net -intf_net sobel_filter_0_if_AP_CTRL [get_bd_intf_pins sobel_filter_0/ap_ctrl] [get_bd_intf_pins sobel_filter_0_if/AP_CTRL]
  connect_bd_intf_net -intf_net sobel_filter_0_if_M_AXIS_0 [get_bd_intf_pins diff_image_0_if/S_AXIS_1] [get_bd_intf_pins sobel_filter_0_if/M_AXIS_0]
  connect_bd_intf_net -intf_net sobel_filter_0_inter_pix [get_bd_intf_pins sobel_filter_0/inter_pix] [get_bd_intf_pins sobel_filter_0_if/AP_FIFO_IARG_0]
  connect_bd_intf_net -intf_net sobel_filter_0_output_edge [get_bd_intf_pins sobel_filter_0/output_edge] [get_bd_intf_pins sobel_filter_0_if/AP_FIFO_OARG_0]
  connect_bd_intf_net -intf_net sobel_filter_pass_0_if_AP_CTRL [get_bd_intf_pins sobel_filter_pass_0/ap_ctrl] [get_bd_intf_pins sobel_filter_pass_0_if/AP_CTRL]
  connect_bd_intf_net -intf_net sobel_filter_pass_0_if_M_AXIS_0 [get_bd_intf_pins diff_image_0_if/S_AXIS_0] [get_bd_intf_pins sobel_filter_pass_0_if/M_AXIS_0]
  connect_bd_intf_net -intf_net sobel_filter_pass_0_if_M_AXIS_1 [get_bd_intf_pins diff_image_0_if/S_AXIS_2] [get_bd_intf_pins sobel_filter_pass_0_if/M_AXIS_1]
  connect_bd_intf_net -intf_net sobel_filter_pass_0_inter_pix [get_bd_intf_pins sobel_filter_pass_0/inter_pix] [get_bd_intf_pins sobel_filter_pass_0_if/AP_FIFO_IARG_0]
  connect_bd_intf_net -intf_net sobel_filter_pass_0_original_pix [get_bd_intf_pins sobel_filter_pass_0/original_pix] [get_bd_intf_pins sobel_filter_pass_0_if/AP_FIFO_OARG_1]
  connect_bd_intf_net -intf_net sobel_filter_pass_0_output_edge [get_bd_intf_pins sobel_filter_pass_0/output_edge] [get_bd_intf_pins sobel_filter_pass_0_if/AP_FIFO_OARG_0]
  connect_bd_intf_net -intf_net vdma_AXIS_video_out [get_bd_intf_pins axi_vdma_0/M_AXIS_MM2S] [get_bd_intf_pins imageon_hdmi_out/AXIS_vid_in]
  connect_bd_intf_net -intf_net vdma_M00_AXI [get_bd_intf_pins axi_interconnect_0/M00_AXI] [get_bd_intf_pins processing_system7_0/S_AXI_HP0]
  connect_bd_intf_net -intf_net video_in_AXIS_vid_out [get_bd_intf_pins axi_vdma_0/S_AXIS_S2MM] [get_bd_intf_pins imageon_hdmi_in/video_out]

  # Create port connections
  connect_bd_net -net HDMI_vid_in_clk_1 [get_bd_ports hdmii_clk] [get_bd_pins imageon_hdmi_in/vid_io_in_clk]
  connect_bd_net -net clk_gen_clk_variable [get_bd_pins clkgen_variable/clk_out1] [get_bd_pins imageon_hdmi_out/vid_out_clk]
  connect_bd_net -net clk_wiz_1_clk_out2 [get_bd_pins clk_wiz_1/clk_out2] [get_bd_pins proc_sys_reset_120MHz/slowest_sync_clk]
  connect_bd_net -net clk_wiz_1_clk_out3 [get_bd_pins clk_wiz_1/clk_out3] [get_bd_pins proc_sys_reset_100MHz/slowest_sync_clk]
  connect_bd_net -net clk_wiz_1_clk_out4 [get_bd_pins clk_wiz_1/clk_out4] [get_bd_pins proc_sys_reset_75MHz/slowest_sync_clk]
  connect_bd_net -net clkgen_150_MHz_clk_out1 [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M00_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M01_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M02_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M03_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M04_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M05_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M06_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M07_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M08_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M09_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M10_ACLK] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/S00_ACLK] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP1/ACLK] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP1/M00_ACLK] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP1/S00_ACLK] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP1/S01_ACLK] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/ACLK] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/M00_ACLK] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/S00_ACLK] [get_bd_pins axi_interconnect_0/ACLK] [get_bd_pins axi_interconnect_0/M00_ACLK] [get_bd_pins axi_interconnect_0/S00_ACLK] [get_bd_pins axi_interconnect_0/S01_ACLK] [get_bd_pins axi_vdma_0/m_axi_mm2s_aclk] [get_bd_pins axi_vdma_0/m_axi_s2mm_aclk] [get_bd_pins axi_vdma_0/m_axis_mm2s_aclk] [get_bd_pins axi_vdma_0/s_axis_s2mm_aclk] [get_bd_pins clk_wiz_1/clk_out1] [get_bd_pins combo_image_0/ap_clk] [get_bd_pins combo_image_0_if/aclk] [get_bd_pins combo_image_0_if/m_axis_aclk] [get_bd_pins combo_image_0_if/s_axi_aclk] [get_bd_pins combo_image_0_if/s_axis_aclk] [get_bd_pins diff_image_0/ap_clk] [get_bd_pins diff_image_0_if/aclk] [get_bd_pins diff_image_0_if/m_axis_aclk] [get_bd_pins diff_image_0_if/s_axi_aclk] [get_bd_pins diff_image_0_if/s_axis_aclk] [get_bd_pins dm_0/m_axi_mm2s_aclk] [get_bd_pins dm_0/s_axi_lite_aclk] [get_bd_pins dm_1/m_axi_mm2s_aclk] [get_bd_pins dm_1/s_axi_lite_aclk] [get_bd_pins dm_2/m_axi_s2mm_aclk] [get_bd_pins dm_2/s_axi_lite_aclk] [get_bd_pins ext_0/ap_clk] [get_bd_pins ext_0_if/aclk] [get_bd_pins ext_0_if/m_axis_aclk] [get_bd_pins ext_0_if/s_axi_aclk] [get_bd_pins ext_0_if/s_axis_aclk] [get_bd_pins imageon_hdmi_in/aclk] [get_bd_pins imageon_hdmi_out/axis_clk] [get_bd_pins median_char_filter_pass_0/ap_clk] [get_bd_pins median_char_filter_pass_0_if/aclk] [get_bd_pins median_char_filter_pass_0_if/m_axis_aclk] [get_bd_pins median_char_filter_pass_0_if/s_axi_aclk] [get_bd_pins median_char_filter_pass_0_if/s_axis_aclk] [get_bd_pins pad_0/ap_clk] [get_bd_pins pad_0_if/aclk] [get_bd_pins pad_0_if/m_axis_aclk] [get_bd_pins pad_0_if/s_axi_aclk] [get_bd_pins pad_0_if/s_axis_aclk] [get_bd_pins pad_1/ap_clk] [get_bd_pins pad_1_if/aclk] [get_bd_pins pad_1_if/m_axis_aclk] [get_bd_pins pad_1_if/s_axi_aclk] [get_bd_pins pad_1_if/s_axis_aclk] [get_bd_pins proc_sys_reset_150MHz/slowest_sync_clk] [get_bd_pins processing_system7_0/M_AXI_GP1_ACLK] [get_bd_pins processing_system7_0/S_AXI_HP0_ACLK] [get_bd_pins processing_system7_0/S_AXI_HP1_ACLK] [get_bd_pins processing_system7_0/S_AXI_HP2_ACLK] [get_bd_pins sobel_filter_0/ap_clk] [get_bd_pins sobel_filter_0_if/aclk] [get_bd_pins sobel_filter_0_if/m_axis_aclk] [get_bd_pins sobel_filter_0_if/s_axi_aclk] [get_bd_pins sobel_filter_0_if/s_axis_aclk] [get_bd_pins sobel_filter_pass_0/ap_clk] [get_bd_pins sobel_filter_pass_0_if/aclk] [get_bd_pins sobel_filter_pass_0_if/m_axis_aclk] [get_bd_pins sobel_filter_pass_0_if/s_axi_aclk] [get_bd_pins sobel_filter_pass_0_if/s_axis_aclk]
  connect_bd_net -net clkgen_150_MHz_locked [get_bd_pins clk_wiz_1/locked] [get_bd_pins proc_sys_reset_100MHz/dcm_locked] [get_bd_pins proc_sys_reset_120MHz/dcm_locked] [get_bd_pins proc_sys_reset_150MHz/dcm_locked] [get_bd_pins proc_sys_reset_50MHz/dcm_locked] [get_bd_pins proc_sys_reset_75MHz/dcm_locked]
  connect_bd_net -net combo_image_0_if_ap_iscalar_0_dout [get_bd_pins combo_image_0/pass_through_option] [get_bd_pins combo_image_0_if/ap_iscalar_0_dout]
  connect_bd_net -net combo_image_0_if_aresetn [get_bd_pins combo_image_0/ap_rst_n] [get_bd_pins combo_image_0_if/aresetn]
  connect_bd_net -net diff_image_0_if_aresetn [get_bd_pins diff_image_0/ap_rst_n] [get_bd_pins diff_image_0_if/aresetn]
  connect_bd_net -net dm_0_mm2s_introut [get_bd_pins dm_0/mm2s_introut] [get_bd_pins xlconcat_0/In0]
  connect_bd_net -net dm_1_mm2s_introut [get_bd_pins dm_1/mm2s_introut] [get_bd_pins xlconcat_0/In1]
  connect_bd_net -net dm_2_s2mm_introut [get_bd_pins dm_2/s2mm_introut] [get_bd_pins xlconcat_0/In2]
  connect_bd_net -net ext_0_if_aresetn [get_bd_pins ext_0/ap_rst_n] [get_bd_pins ext_0_if/aresetn]
  connect_bd_net -net fmc2_imageon_iic_gpo [get_bd_ports imageon_reset] [get_bd_pins fmc2_imageon_iic/gpo]
  connect_bd_net -net interconnect_resetn_1 [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M00_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M01_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M02_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M03_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M04_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M05_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M06_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M07_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M08_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M09_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/M10_ARESETN] [get_bd_pins axi_ic_processing_system7_0_M_AXI_GP1/S00_ARESETN] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP1/ARESETN] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP1/M00_ARESETN] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP1/S00_ARESETN] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP1/S01_ARESETN] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/ARESETN] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/M00_ARESETN] [get_bd_pins axi_ic_processing_system7_0_S_AXI_HP2/S00_ARESETN] [get_bd_pins axi_interconnect_0/ARESETN] [get_bd_pins proc_sys_reset_150MHz/interconnect_aresetn]
  connect_bd_net -net median_char_filter_pass_0_if_ap_iscalar_0_dout [get_bd_pins median_char_filter_pass_0/threshold] [get_bd_pins median_char_filter_pass_0_if/ap_iscalar_0_dout]
  connect_bd_net -net median_char_filter_pass_0_if_aresetn [get_bd_pins median_char_filter_pass_0/ap_rst_n] [get_bd_pins median_char_filter_pass_0_if/aresetn]
  connect_bd_net -net pad_0_if_aresetn [get_bd_pins pad_0/ap_rst_n] [get_bd_pins pad_0_if/aresetn]
  connect_bd_net -net pad_1_if_aresetn [get_bd_pins pad_1/ap_rst_n] [get_bd_pins pad_1_if/aresetn]
  connect_bd_net -net processing_system7_0_FCLK_CLK0 [get_bd_pins axi_vdma_0/s_axi_lite_aclk] [get_bd_pins clk_wiz_1/clk_in1] [get_bd_pins clkgen_variable/clk_in1] [get_bd_pins clkgen_variable/s_axi_aclk] [get_bd_pins fmc2_imageon_iic/s_axi_aclk] [get_bd_pins imageon_hdmi_out/axi_lite_clk] [get_bd_pins proc_sys_reset_50MHz/slowest_sync_clk] [get_bd_pins processing_system7_0/FCLK_CLK0] [get_bd_pins processing_system7_0/M_AXI_GP0_ACLK] [get_bd_pins processing_system7_0_axi_periph/ACLK] [get_bd_pins processing_system7_0_axi_periph/M00_ACLK] [get_bd_pins processing_system7_0_axi_periph/M01_ACLK] [get_bd_pins processing_system7_0_axi_periph/M02_ACLK] [get_bd_pins processing_system7_0_axi_periph/M03_ACLK] [get_bd_pins processing_system7_0_axi_periph/S00_ACLK]
  connect_bd_net -net processing_system7_0_FCLK_RESET0_N [get_bd_pins clk_wiz_1/resetn] [get_bd_pins proc_sys_reset_100MHz/ext_reset_in] [get_bd_pins proc_sys_reset_120MHz/ext_reset_in] [get_bd_pins proc_sys_reset_150MHz/ext_reset_in] [get_bd_pins proc_sys_reset_50MHz/ext_reset_in] [get_bd_pins proc_sys_reset_75MHz/ext_reset_in] [get_bd_pins processing_system7_0/FCLK_RESET0_N]
  connect_bd_net -net rst_processing_system7_0_50M_interconnect_aresetn [get_bd_pins proc_sys_reset_50MHz/interconnect_aresetn] [get_bd_pins processing_system7_0_axi_periph/ARESETN]
  connect_bd_net -net rst_processing_system7_0_50M_peripheral_aresetn [get_bd_pins axi_vdma_0/axi_resetn] [get_bd_pins clkgen_variable/s_axi_aresetn] [get_bd_pins fmc2_imageon_iic/s_axi_aresetn] [get_bd_pins imageon_hdmi_out/axi_lite_resetn] [get_bd_pins proc_sys_reset_50MHz/peripheral_aresetn] [get_bd_pins processing_system7_0_axi_periph/M00_ARESETN] [get_bd_pins processing_system7_0_axi_periph/M01_ARESETN] [get_bd_pins processing_system7_0_axi_periph/M02_ARESETN] [get_bd_pins processing_system7_0_axi_periph/M03_ARESETN] [get_bd_pins processing_system7_0_axi_periph/S00_ARESETN]
  connect_bd_net -net rst_sync_to_axis_clk_peripheral_aresetn [get_bd_pins axi_interconnect_0/M00_ARESETN] [get_bd_pins axi_interconnect_0/S00_ARESETN] [get_bd_pins axi_interconnect_0/S01_ARESETN] [get_bd_pins combo_image_0_if/m_axis_aresetn] [get_bd_pins combo_image_0_if/s_axi_aresetn] [get_bd_pins combo_image_0_if/s_axis_aresetn] [get_bd_pins diff_image_0_if/m_axis_aresetn] [get_bd_pins diff_image_0_if/s_axi_aresetn] [get_bd_pins diff_image_0_if/s_axis_aresetn] [get_bd_pins dm_0/axi_resetn] [get_bd_pins dm_1/axi_resetn] [get_bd_pins dm_2/axi_resetn] [get_bd_pins ext_0_if/m_axis_aresetn] [get_bd_pins ext_0_if/s_axi_aresetn] [get_bd_pins ext_0_if/s_axis_aresetn] [get_bd_pins imageon_hdmi_in/aresetn] [get_bd_pins imageon_hdmi_out/axis_resetn] [get_bd_pins median_char_filter_pass_0_if/m_axis_aresetn] [get_bd_pins median_char_filter_pass_0_if/s_axi_aresetn] [get_bd_pins median_char_filter_pass_0_if/s_axis_aresetn] [get_bd_pins pad_0_if/m_axis_aresetn] [get_bd_pins pad_0_if/s_axi_aresetn] [get_bd_pins pad_0_if/s_axis_aresetn] [get_bd_pins pad_1_if/m_axis_aresetn] [get_bd_pins pad_1_if/s_axi_aresetn] [get_bd_pins pad_1_if/s_axis_aresetn] [get_bd_pins proc_sys_reset_150MHz/peripheral_aresetn] [get_bd_pins sobel_filter_0_if/m_axis_aresetn] [get_bd_pins sobel_filter_0_if/s_axi_aresetn] [get_bd_pins sobel_filter_0_if/s_axis_aresetn] [get_bd_pins sobel_filter_pass_0_if/m_axis_aresetn] [get_bd_pins sobel_filter_pass_0_if/s_axi_aresetn] [get_bd_pins sobel_filter_pass_0_if/s_axis_aresetn]
  connect_bd_net -net sobel_filter_0_if_aresetn [get_bd_pins sobel_filter_0/ap_rst_n] [get_bd_pins sobel_filter_0_if/aresetn]
  connect_bd_net -net sobel_filter_pass_0_if_aresetn [get_bd_pins sobel_filter_pass_0/ap_rst_n] [get_bd_pins sobel_filter_pass_0_if/aresetn]
  connect_bd_net -net xlconcat_0_dout [get_bd_pins processing_system7_0/IRQ_F2P] [get_bd_pins xlconcat_0/dout]

  # Create address segments
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces axi_vdma_0/Data_MM2S] [get_bd_addr_segs processing_system7_0/S_AXI_HP0/HP0_DDR_LOWOCM] SEG_processing_system7_0_HP0_DDR_LOWOCM
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces axi_vdma_0/Data_S2MM] [get_bd_addr_segs processing_system7_0/S_AXI_HP0/HP0_DDR_LOWOCM] SEG_processing_system7_0_HP0_DDR_LOWOCM
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces dm_0/Data_MM2S] [get_bd_addr_segs processing_system7_0/S_AXI_HP1/HP1_DDR_LOWOCM] SEG_processing_system7_0_HP1_DDR_LOWOCM
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces dm_1/Data_MM2S] [get_bd_addr_segs processing_system7_0/S_AXI_HP2/HP2_DDR_LOWOCM] SEG_processing_system7_0_HP2_DDR_LOWOCM
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces dm_2/Data_S2MM] [get_bd_addr_segs processing_system7_0/S_AXI_HP1/HP1_DDR_LOWOCM] SEG_processing_system7_0_HP1_DDR_LOWOCM
  create_bd_addr_seg -range 0x10000 -offset 0x43000000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs axi_vdma_0/S_AXI_LITE/Reg] SEG_axi_vdma_0_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x43C00000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs clkgen_variable/s_axi_lite/Reg] SEG_clkgen_variable_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x83C00000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs combo_image_0_if/S_AXI/Reg] SEG_combo_image_0_if_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x83C10000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs diff_image_0_if/S_AXI/Reg] SEG_diff_image_0_if_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x80400000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs dm_0/S_AXI_LITE/Reg] SEG_dm_0_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x80410000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs dm_1/S_AXI_LITE/Reg] SEG_dm_1_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x80420000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs dm_2/S_AXI_LITE/Reg] SEG_dm_2_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x83C20000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs ext_0_if/S_AXI/Reg] SEG_ext_0_if_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x41600000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs fmc2_imageon_iic/S_AXI/Reg] SEG_fmc2_imageon_iic_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x83C30000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs median_char_filter_pass_0_if/S_AXI/Reg] SEG_median_char_filter_pass_0_if_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x83C40000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs pad_0_if/S_AXI/Reg] SEG_pad_0_if_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x83C50000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs pad_1_if/S_AXI/Reg] SEG_pad_1_if_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x83C60000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs sobel_filter_0_if/S_AXI/Reg] SEG_sobel_filter_0_if_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x83C70000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs sobel_filter_pass_0_if/S_AXI/Reg] SEG_sobel_filter_pass_0_if_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x43C10000 [get_bd_addr_spaces processing_system7_0/Data] [get_bd_addr_segs imageon_hdmi_out/v_tc_0/ctrl/Reg] SEG_v_tc_0_Reg

  # Perform GUI Layout
  regenerate_bd_layout -layout_string {
   DisplayTieOff: "1",
   guistr: "# # String gsaved with Nlview 6.5.5  2015-06-26 bk=1.3371 VDI=38 GEI=35 GUI=JA:1.6
#  -string -flagsOSRD
preplace port hdmio -pg 1 -y 740 -defaultsOSRD
preplace port DDR -pg 1 -y 120 -defaultsOSRD
preplace port hdmii_clk -pg 1 -y 880 -defaultsOSRD
preplace port imageon_iic -pg 1 -y 550 -defaultsOSRD
preplace port hdmii -pg 1 -y 860 -defaultsOSRD
preplace port FIXED_IO -pg 1 -y 140 -defaultsOSRD
preplace portBus imageon_reset -pg 1 -y 590 -defaultsOSRD
preplace inst proc_sys_reset_100MHz -pg 1 -lvl 2 -y 80 -defaultsOSRD
preplace inst proc_sys_reset_150MHz -pg 1 -lvl 2 -y 770 -defaultsOSRD
preplace inst axi_vdma_0 -pg 1 -lvl 4 -y 890 -defaultsOSRD
preplace inst fmc2_imageon_iic -pg 1 -lvl 6 -y 570 -defaultsOSRD
preplace inst imageon_hdmi_in -pg 1 -lvl 3 -y 890 -defaultsOSRD
preplace inst proc_sys_reset_120MHz -pg 1 -lvl 2 -y 240 -defaultsOSRD
preplace inst proc_sys_reset_75MHz -pg 1 -lvl 2 -y 420 -defaultsOSRD
preplace inst xlconcat_0 -pg 1 -lvl 5 -y 210 -defaultsOSRD
preplace inst proc_sys_reset_50MHz -pg 1 -lvl 2 -y 580 -defaultsOSRD
preplace inst imageon_hdmi_out -pg 1 -lvl 6 -y 740 -defaultsOSRD
preplace inst axi_interconnect_0 -pg 1 -lvl 5 -y 920 -defaultsOSRD
preplace inst clkgen_variable -pg 1 -lvl 4 -y 660 -defaultsOSRD
preplace inst clk_wiz_1 -pg 1 -lvl 1 -y 360 -defaultsOSRD
preplace inst processing_system7_0_axi_periph -pg 1 -lvl 3 -y 580 -defaultsOSRD
preplace inst processing_system7_0 -pg 1 -lvl 6 -y 230 -defaultsOSRD
preplace netloc processing_system7_0_DDR 1 6 1 NJ
preplace netloc fmc2_imageon_iic_gpo 1 6 1 NJ
preplace netloc clkgen_150_MHz_locked 1 1 1 200
preplace netloc HDMI_vid_in_clk_1 1 0 3 NJ 880 NJ 880 NJ
preplace netloc vdma_AXIS_video_out 1 4 2 1250 680 NJ
preplace netloc processing_system7_0_axi_periph_M03_AXI 1 3 1 890
preplace netloc processing_system7_0_axi_periph_M00_AXI 1 3 3 N 550 NJ 550 NJ
preplace netloc rst_processing_system7_0_50M_interconnect_aresetn 1 2 1 560
preplace netloc axi_vdma_0_M_AXI_MM2S 1 4 1 N
preplace netloc fmc_imageon_hdmi_out_0_IO_HDMIO 1 6 1 NJ
preplace netloc processing_system7_0_M_AXI_GP0 1 2 5 560 390 NJ 390 NJ 390 NJ 390 2070
preplace netloc HDMI_vid_in_1 1 0 3 NJ 860 NJ 860 NJ
preplace netloc processing_system7_0_FCLK_RESET0_N 1 0 7 10 270 230 330 NJ 330 NJ 330 NJ 330 NJ 400 2060
preplace netloc clk_gen_clk_variable 1 4 2 NJ 650 1590
preplace netloc rst_processing_system7_0_50M_peripheral_aresetn 1 2 4 580 770 890 740 NJ 740 1630
preplace netloc processing_system7_0_axi_periph_M02_AXI 1 3 1 910
preplace netloc vdma_M00_AXI 1 5 1 1600
preplace netloc xlconcat_0_dout 1 5 1 1590
preplace netloc processing_system7_0_FIXED_IO 1 6 1 NJ
preplace netloc video_in_AXIS_vid_out 1 3 1 930
preplace netloc fmc2_imageon_iic_IIC 1 6 1 NJ
preplace netloc clk_wiz_1_clk_out2 1 1 1 220
preplace netloc rst_sync_to_axis_clk_peripheral_aresetn 1 2 4 570 1020 NJ 1020 1280 770 NJ
preplace netloc interconnect_resetn_1 1 2 3 NJ 790 NJ 770 1260
preplace netloc clkgen_150_MHz_clk_out1 1 1 5 190 870 580 800 880 1010 1270 760 1620
preplace netloc clk_wiz_1_clk_out3 1 1 1 210
preplace netloc processing_system7_0_FCLK_CLK0 1 0 7 20 540 220 670 570 760 920 570 NJ 570 1640 410 2080
preplace netloc axi_vdma_0_M_AXI_S2MM 1 4 1 N
preplace netloc clk_wiz_1_clk_out4 1 1 1 N
preplace netloc processing_system7_0_axi_periph_M01_AXI 1 3 3 NJ 580 NJ 580 1610
levelinfo -pg 1 -10 110 400 730 1090 1430 1850 2100 -top 0 -bot 1070
",
}

  # Restore current instance
  current_bd_instance $oldCurInst

  save_bd_design
}
# End of create_root_design()


##################################################################
# MAIN FLOW
##################################################################

create_root_design ""


